-- MySQL Workbench Synchronization
-- Generated: 2022-05-06 14:33:28
-- Model: nccs
-- Version: D07.03.18
-- Project: idsteServers
-- Author:


SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';

-- 将40（BC02）,48(BC03)开头的设备的devType 的bit0 (是否有集控功能)置为0
UPDATE DeviceList SET DevType=DevType&~1 WHERE SUBSTR(DevID,1,2) IN ('40','48');

CREATE TABLE IF NOT EXISTS `nccs`.`DevUsedStatus`  (
  `DevID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '融合终端，音视频直转播终端，mic等设备的ID(因为mic可能从一个设备挪到另一个设备使用所以单独为mic创建记录)',
  `Type` int(10) NOT NULL COMMENT '用于区分设备类型(0:融合终端 1:空调 2:电源 10:音视频直转播终端 11:麦克风 12:网关设备  )',
  `Status` enum('offline','online','pwrOn','pwrOff','using','isPushing') CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT 'offline:离线 online:在线 pwrOn:开机 pwrOff:关机 using:使用中 isPushing:推流中',
  `ContinueOffline` tinyint(10) NOT NULL DEFAULT 0 COMMENT '当status= offline时有效。1：表示设备当天一直离线 0：表示离线后又上线',
  `UpdateDate` date NOT NULL DEFAULT '2022-04-19' COMMENT 'mic和充电桩上报该状态时的时间',
  `Count` int(10) NOT NULL COMMENT '设备切换为该状态的次数',
  `SchoolID` int(10) NOT NULL COMMENT '所在学校ID',
  UNIQUE INDEX `Dev_Status_Date`(`DevID`, `Status`, `UpdateDate`, `SchoolID`, `Type`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;


CREATE TABLE IF NOT EXISTS `nccs`.`MicPhoneList`  (
  `id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT 'mic的id',
  `name` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT 'mic的名称',
  `mic_type` int(32) NOT NULL DEFAULT 0 COMMENT '麦克风类型',
  `last_dev_id` varchar(255) NOT NULL DEFAULT '' COMMENT '最近一次归属的设备ID',
  `charge_count` int(32) NOT NULL DEFAULT 0 COMMENT '充电次数',
  `school_id` int(10) NOT NULL,
  `update_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `create_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

CREATE TABLE IF NOT EXISTS `nccs`.`MicStubList`  (
  `id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '充电桩id',
  `name` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '充电桩名称',
  `stub_type` int(32) NOT NULL DEFAULT 0 COMMENT '充电桩类型',
  `last_dev_id` varchar(255) NOT NULL DEFAULT '' COMMENT '最近一次归属的设备ID',
  `school_id` int(10) NOT NULL,
  `update_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `create_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;





CREATE TABLE IF NOT EXISTS `nccs`.`SessionHistory` (
  `SessionID` smallint(6) NOT NULL COMMENT '任务ID',
  `SessionStreamType` tinyint(4) NOT NULL COMMENT '任务内容类型',
  `SourceMode` tinyint(4) NOT NULL COMMENT '来源方式',
  `SessionType` tinyint(4) NOT NULL COMMENT '任务类型',
  `SessionName` varchar(50) NOT NULL COMMENT '任务名称',
  `ScheduleID` int(11) NOT NULL COMMENT '执行时间ID，手动任务为0',
  `ScheduleTime` time NOT NULL COMMENT '执行时间',
  `Status` tinyint(4) NOT NULL COMMENT '执行状态 0：待执行，1:执行中，2：执行成功，3：执行失败',
  `SchoolID` int(11) NOT NULL COMMENT '学校ID',
  `HistoryDate` date NOT NULL COMMENT '任务当日时间',
  UNIQUE KEY `SessionID` (`SessionID`,`ScheduleID`,`SchoolID`,`HistoryDate`,`ScheduleTime`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


-- 图文任务表增加停止播放时间字段
ALTER TABLE `nccs`.`GraphicSessions` ADD COLUMN `update_status_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '任务状态更新时间' AFTER `create_time` ;

CREATE TABLE IF NOT EXISTS `nccs`.`ReportData` (
  `table_id` int(11) NOT NULL COMMENT '报表ID',
  `row_id` varchar(255) NOT NULL COMMENT '报表周期 例：按月分组 ‘2022-01’，‘2022-02’',
  `header_column_id` int(11) NOT NULL COMMENT '子项关联ID ',
  `base_id` varchar(255) NOT NULL COMMENT '按设备统计含义为 ：device_id 。按学校统计 含义为 ：school_id 按学校-设备统计：school_id-device-id ',
  `val` varchar(255) NOT NULL COMMENT '具体数据值',
  UNIQUE KEY `table_id` (`table_id`,`row_id`,`header_column_id`,`base_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

-- 移除掉无物联控制的物联配置
DELETE `nccs`.`RfConfig` FROM `nccs`.`RfConfig` INNER JOIN DeviceList b on b.DevID=`nccs`.`RfConfig`.DevID WHERE b.DevType&0x20=0;

SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;