﻿-- MySQL Workbench Forward Engineering

SET @OLD_UNIQUE_CHECKS=@@UNIQUE_CHECKS, UNIQUE_CHECKS=0;
SET @OLD_FOREIGN_KEY_CHECKS=@@FOREIGN_KEY_CHECKS, FOREIGN_KEY_CHECKS=0;
SET @OLD_SQL_MODE=@@SQL_MODE, SQL_MODE='TRADITIONAL,ALLOW_INVALID_DATES';

-- -----------------------------------------------------
-- Schema mydb
-- -----------------------------------------------------
-- -----------------------------------------------------
-- Schema nccs
-- -----------------------------------------------------

-- -----------------------------------------------------
-- Schema nccs
-- -----------------------------------------------------
CREATE SCHEMA IF NOT EXISTS `nccs` DEFAULT CHARACTER SET utf8 ;
USE `nccs` ;

-- -----------------------------------------------------
-- Table `nccs`.`AlternateDate`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`AlternateDate` ;

CREATE TABLE `nccs`.`AlternateDate`  (
  `SpecialDate` date NOT NULL,
  `AlteredScheduleDay` tinyint(4) NULL DEFAULT NULL,
  `SchoolID` int(11) NOT NULL DEFAULT 0,
  INDEX `schoolIndex`(`SchoolID`) USING BTREE,
  UNIQUE INDEX `date_school`(`SpecialDate`, `SchoolID`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;


-- -----------------------------------------------------
-- Table `nccs`.`BaseInfo`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`BaseInfo` ;

CREATE TABLE IF NOT EXISTS `nccs`.`BaseInfo` (
  `InfomationID` INT(11) NOT NULL DEFAULT '0' COMMENT '0~0x04 : air condition command description;\n0x80: User name;\n0x100: MediaFile auto_increasement value;\n0x101 Active task template;\n0x200: Version;',
  `Description` VARCHAR(1024) NULL DEFAULT NULL,
  `InfoValue` INT(11) NULL DEFAULT NULL,
  `SchoolID` INT(11) NOT NULL DEFAULT '0',
  UNIQUE INDEX `index` USING BTREE (`InfomationID` ASC, `SchoolID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`BroadcastMode`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`BroadcastMode` ;

CREATE TABLE IF NOT EXISTS `nccs`.`BroadcastMode` (
  `idBroadcastMode` INT(11) NOT NULL AUTO_INCREMENT,
  `ModeName` VARCHAR(50) NULL DEFAULT NULL,
  `Priority` INT(11) NOT NULL DEFAULT '10',
  `Enabled` TINYINT(1) NULL DEFAULT '0',
  `StartTime` DATETIME NULL DEFAULT NULL,
  `StopTime` DATETIME NULL DEFAULT NULL,
  `TimeStyle` TINYINT(4) NULL DEFAULT '0' COMMENT '0: means for one day\n   the start date and end date is indicated by starttime and stoptime.\n\nother: means the mode should be repeated weekly.\nbit 0: means sunday\nbit1:  monday\nbit2: tuesday\n...',
  `Active` TINYINT(1) NOT NULL DEFAULT '0',
  `StartEntryID` INT(11) NOT NULL DEFAULT '0',
  `StopEntryID` INT(11) NOT NULL DEFAULT '0',
  `SchoolID` INT(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`idBroadcastMode`),
  INDEX `schoolIndex` USING BTREE (`SchoolID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`DevClasses`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DevClasses` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DevClasses` (
  `ClassID` INT(11) NOT NULL AUTO_INCREMENT,
  `Name` VARCHAR(50) NULL DEFAULT NULL,
  `Parent` INT(11) NULL DEFAULT NULL,
  `SchoolID` INT(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`ClassID`),
  INDEX `ClassParent` (`Parent` ASC),
  INDEX `schoolIndex` USING BTREE (`SchoolID` ASC),
  CONSTRAINT `ClassParent`
    FOREIGN KEY (`Parent`)
    REFERENCES `nccs`.`DevClasses` (`ClassID`)
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`DeviceList`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceList` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DeviceList` (
  `DevID` VARCHAR(50) NOT NULL,
  `Dev_Name` VARCHAR(32) NULL DEFAULT NULL,
  `Parent` INT(11) NULL DEFAULT NULL,
  `DisableParentSchedule` TINYINT(4) NULL DEFAULT '0' COMMENT 'Indicate whether disable inheritting schedule setting from parents groups.',
  `Dev_Description` VARBINARY(96) NULL DEFAULT NULL,
  `Dev_Configuration` VARBINARY(2048) NULL DEFAULT NULL,
  `RtspUrl` VARCHAR(512) NULL DEFAULT NULL,
  `RtspSub` VARCHAR(512) NULL DEFAULT NULL,
  `RtspUrl1` VARCHAR(512) NULL DEFAULT NULL,
  `RtspSub1` VARCHAR(512) NULL DEFAULT NULL,
  `ProjWatermark` INT(10) UNSIGNED NOT NULL DEFAULT '360000000',
  `ProjUsedTime` INT(10) UNSIGNED NOT NULL DEFAULT '0',
  `Dev_ConfigurationV2` VARCHAR(16384) NULL DEFAULT NULL,
  `PcIp` VARCHAR(41) NULL DEFAULT NULL,
  `PcPort` INT(10) UNSIGNED NULL DEFAULT NULL,
  `PcMainPasswd` VARCHAR(32) NULL DEFAULT NULL,
  `PcViewPasswd` VARCHAR(32) NULL DEFAULT NULL,
  `RfInvalid` INT(10) UNSIGNED NULL DEFAULT '0',
  `Ip` VARCHAR(50) NULL DEFAULT NULL,
  `Proto` INT(10) NULL DEFAULT '1',
  `DevType` INT(11) NOT NULL DEFAULT '0',
  `SchoolID` INT(11) NOT NULL DEFAULT '0',
  `DoubleClass` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否支持双师课堂 0-不支持 1-支持',
  PRIMARY KEY (`DevID`),
  UNIQUE INDEX `DevID_UNIQUE` (`DevID` ASC),
  INDEX `DevClass` (`Parent` ASC),
  CONSTRAINT `DevClass`
    FOREIGN KEY (`Parent`)
    REFERENCES `nccs`.`DevClasses` (`ClassID`)
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Table `nccs`.`DevStartingPic`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DevStartingPic`;

CREATE TABLE IF NOT EXISTS `nccs`.`DevStartingPic`  (
  `SchoolID` int(11) NOT NULL DEFAULT 0 COMMENT '所属学校ID',
  `Type` tinyint(4) NOT NULL COMMENT '图片类型，0---TM03背景图，1---TM03前景图，2---面板开机图片',
  `User` int(11) NULL DEFAULT NULL COMMENT '上传用户ID',
  `Path` varchar(255) NOT NULL COMMENT '文件路径',
  `SyncVal` int(11) NOT NULL DEFAULT 1 COMMENT '整数同步字',
  PRIMARY KEY (`SchoolID`, `Type`) USING BTREE)
ENGINE = InnoDB
CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Table `nccs`.`BrdModeMember`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`BrdModeMember` ;

CREATE TABLE IF NOT EXISTS `nccs`.`BrdModeMember` (
  `DevIDMode` INT(11) NOT NULL AUTO_INCREMENT,
  `BrdModeID` INT(11) NOT NULL,
  `DeviceID` VARCHAR(50) NOT NULL,
  PRIMARY KEY (`DevIDMode`),
  UNIQUE INDEX `DevIDMode_UNIQUE` (`BrdModeID` ASC, `DeviceID` ASC),
  INDEX `BrdModeID` (`BrdModeID` ASC),
  INDEX `ModeDeviceID` (`DeviceID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`CallWaiter`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`CallWaiter` ;

CREATE TABLE IF NOT EXISTS `nccs`.`CallWaiter` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `user` INT(11) NOT NULL,
  `session` VARCHAR(45) NOT NULL,
  `updateAt` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `session_unique` (`session` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`DevCtrlSchedule`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DevCtrlSchedule` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DevCtrlSchedule` (
  `ScheduleID` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
  `DevID` VARCHAR(50) NOT NULL,
  `ActionTime` TIME NOT NULL,
  `Action` INT(11) NULL DEFAULT NULL,
  `WeekDay` TINYINT(4) NOT NULL,
  `State` INT(11) NULL DEFAULT '0',
  `ExtArgs` VARCHAR(256) NULL DEFAULT NULL,
  `Disable` TINYINT(1) NULL DEFAULT '0',
  PRIMARY KEY (`DevID`, `ActionTime`, `WeekDay`),
  UNIQUE INDEX `ScheduleID_UNIQUE` (`ScheduleID` ASC),
  INDEX `DeviD` (`DevID` ASC),
  INDEX `DeviceID` (`DevID` ASC),
  INDEX `DevCtrlDevId` (`DevID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`DeviceAuthSupplyLog`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceAuthSupplyLog` ;

CREATE TABLE `DeviceAuthSupplyLog` (
  `Id` int(11) NOT NULL AUTO_INCREMENT,
  `Type` varchar(255) NOT NULL DEFAULT '' COMMENT '认证类型',
  `Supply` varchar(255) NOT NULL DEFAULT '' COMMENT '供应商',
  `Url` varchar(1024) NOT NULL DEFAULT '' COMMENT '请求URL',
  `ReqInfo` varchar(4096) NOT NULL DEFAULT '' COMMENT '请求数据',
  `ResInfo` varchar(4096) NOT NULL DEFAULT '' COMMENT '响应数据',
  `Result` tinyint(4) NOT NULL DEFAULT '0' COMMENT '请求结果 0-失败 1-成功',
  `ErrorType` tinyint(4) NOT NULL DEFAULT '0' COMMENT '错误类型 0-无错误 1-系统未配置好 2-供应商返回错误 3-人员信息未找到 4-网络出现问题',
  `Error` varchar(4096) NOT NULL DEFAULT '' COMMENT '错误信息',
  `StartTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '开始时间',
  `EndTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '结束时间',
  `UseTime` int(11) NOT NULL DEFAULT '0' COMMENT '耗时（毫秒数）',
  `Sync` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否同步 0-未同步 1-已同步',
  `AddTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '添加时间',
  PRIMARY KEY (`Id`)
) ENGINE=InnoDB AUTO_INCREMENT=0 DEFAULT CHARSET=utf8 COMMENT='设备认证供应商日志';

-- -----------------------------------------------------
-- Table `nccs`.`DeviceDesiredStaus`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceDesiredStaus` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DeviceDesiredStaus` (
  `DeviceID` VARCHAR(50) NOT NULL,
  `SessionID` SMALLINT(5) UNSIGNED NULL DEFAULT NULL,
  `BrdPort` SMALLINT(6) NULL DEFAULT NULL,
  `SessionValid` TINYINT(1) NULL DEFAULT '1',
  `SessionType` TINYINT(4) NULL DEFAULT NULL,
  `StreamType` TINYINT(4) UNSIGNED NULL DEFAULT NULL,
  `SysEnabled` TINYINT(4) NULL DEFAULT NULL,
  `PowerAction` TINYINT(4) NULL DEFAULT NULL,
  `RfDevCtrl` BINARY(16) NULL DEFAULT NULL,
  `RfCtrlAction` BINARY(16) NULL DEFAULT NULL,
  `IpCall` TINYINT(1) NOT NULL DEFAULT '0' COMMENT '0: idle\n1:ringing\n2:talking',
  `IpCallPort` INT(11) NULL DEFAULT NULL,
  `IpCallEvent` DATETIME NULL DEFAULT NULL,
  PRIMARY KEY (`DeviceID`),
  INDEX `DesiredDevicesID` (`DeviceID` ASC),
  INDEX `DesiredSessionID` (`SessionID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`DeviceExt`
-- -----------------------------------------------------
CREATE TABLE IF NOT EXISTS `nccs`.`DeviceExt` (
  `DevID` VARCHAR(50) NOT NULL,
  `Name` VARCHAR(45) NOT NULL,
  `Config` VARCHAR(2048) NOT NULL DEFAULT '{}',
  UNIQUE INDEX `DeviceExt_uni` (`DevID` ASC, `Name` ASC),
  INDEX `DeviceExt_idx` (`DevID` ASC, `Name` ASC),
  CONSTRAINT `DevID`
    FOREIGN KEY (`DevID`)
    REFERENCES `nccs`.`DeviceList` (`DevID`)
    ON DELETE CASCADE
    ON UPDATE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COMMENT = '设备扩展信息表';


-- -----------------------------------------------------
-- Table `nccs`.`DeviceLog`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceLog` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DeviceLog` (
  `DevLogID` BIGINT(20) NOT NULL AUTO_INCREMENT,
  `SchoolID` INT(11) NOT NULL DEFAULT '0',
  `DeviceID` VARCHAR(50) NULL DEFAULT NULL,
  `DeviceName` VARCHAR(255) NOT NULL DEFAULT '' COMMENT '设备位置名称',
  `DateTime` DATETIME NOT NULL,
  `Event` TINYINT(4) NULL DEFAULT NULL COMMENT '1  offline/online\n2  power on/power off\n3  enabled/  disabled\n4  Normal Text Message',
  `CtrlUser` INT(11) NULL DEFAULT NULL,
  `UserName` VARCHAR(255) NOT NULL DEFAULT '' COMMENT '用户姓名',
  `MsgContext` VARCHAR(256) NULL DEFAULT NULL,
  `EndTime` DATETIME NULL DEFAULT NULL,
  PRIMARY KEY (`DevLogID`,`DateTime`),
  INDEX `endTime_idx` USING BTREE (`EndTime` ASC),
  INDEX `dateTime_idx` USING BTREE (`DateTime` ASC),
  INDEX `device_idx` USING BTREE (`DeviceID` ASC, `Event` ASC),
  INDEX `schoolTime` USING BTREE (`DateTime`,`EndTime`,`SchoolID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COMMENT = 'Devices log';


-- -----------------------------------------------------
-- Table `nccs`.`DeviceCtrlList`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceCtrlList` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DeviceCtrlList` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
  `DevID` VARCHAR(50) NOT NULL,
  `SubID` INT(11) NOT NULL,
  `State` INT(11) NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `index` USING BTREE (`DevID` ASC, `SubID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`DeviceStatistic`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceStatistic` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DeviceStatistic` (
  `DeviceID` VARCHAR(50) NOT NULL,
  `StatisticDay` DATE NOT NULL,
  `PowerConsumed` BINARY(128) NULL DEFAULT NULL,
  `UsedTime` BINARY(128) NULL DEFAULT NULL,
  `SchoolID` INT(11) NOT NULL DEFAULT '0',
  `DataState` int(1) DEFAULT NULL,
  PRIMARY KEY (`DeviceID`, `StatisticDay`, `SchoolID`),
  INDEX `StatisticDay` USING BTREE (`StatisticDay` ASC),
  INDEX `schoolIndex` USING BTREE (`SchoolID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`DeviceStatus`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceStatus` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DeviceStatus` (
  `DeviceID` VARCHAR(50) NOT NULL,
  `DeviceType` TINYINT(4) NULL DEFAULT '0',
  `DeviceStatus` INT(11) NULL DEFAULT '0',
  `IpAddress` VARCHAR(50) NULL DEFAULT NULL,
  `ShouldSessionID` SMALLINT(6) UNSIGNED NULL DEFAULT '0',
  `ActualSessionID` SMALLINT(6) UNSIGNED NULL DEFAULT '0',
  `State_SysPower` TINYINT(4) NULL DEFAULT '0',
  `State_ProjectorStatus` TINYINT(4) NULL DEFAULT '0',
  `State_ProjectorLampStatus` TINYINT(4) NULL DEFAULT '0',
  `State_ExDevice1Status` TINYINT(4) NULL DEFAULT '0',
  `State_ExDevice2Status` TINYINT(4) NULL DEFAULT '0',
  `State_CurrProjectorSrc` TINYINT(4) NULL DEFAULT '0',
  `State_CurrAudio` TINYINT(4) NULL DEFAULT '0',
  `State_CurrAudioVolume` TINYINT(4) NULL DEFAULT '0',
  `State_CurrMicVolume` TINYINT(4) NULL DEFAULT '0',
  `State_FaultStatus` TINYINT(4) NULL DEFAULT '0',
  `State_MicState` TINYINT(4) NULL DEFAULT '0',
  `State_Mute` TINYINT(4) NULL DEFAULT '0',
  `State_CentralUsedTime` INT(11) NULL DEFAULT '0',
  `State_ProjectorUsedTime` INT(11) NULL DEFAULT '0',
  `State_LightUsedTime` INT(11) NULL DEFAULT '0',
  `Cfg_System` TINYINT(4) NULL DEFAULT NULL,
  `Cfg_Remark` VARBINARY(96) NULL DEFAULT NULL,
  `netid` TINYINT(4) NULL DEFAULT '-1',
  `NetworkID` INT(11) NULL DEFAULT '0',
  `BrdPort` INT(11) NULL DEFAULT NULL,
  `RfDevStatus` BINARY(16) NULL DEFAULT NULL,
  `State_Pc` TINYINT(4) NULL DEFAULT '0',
  `User_ID` INT(11) NULL DEFAULT NULL,
  `SysPowerCmd` TINYINT(4) NULL DEFAULT NULL COMMENT '0:power off; 1:power on',
  `IpCallStatus` TINYINT(4) UNSIGNED NULL DEFAULT '0',
  `Version` VARCHAR(32) NULL DEFAULT NULL,
  `Temperature` INT(10) UNSIGNED NULL DEFAULT '0',
  `Humidity` INT(10) UNSIGNED NULL DEFAULT '0',
  `Trouble` INT(10) UNSIGNED NULL DEFAULT NULL,
  `Recorder` INT(10) UNSIGNED NULL DEFAULT NULL,
  `Scene` INT(10) UNSIGNED NULL DEFAULT NULL,
  `Protocol` INT(10) NULL DEFAULT '1',
  PRIMARY KEY (`DeviceID`),
  UNIQUE INDEX `DeviceID_UNIQUE` (`DeviceID` ASC),
  INDEX `DevID` (`DeviceID` ASC),
  INDEX `DevicestatusNetworkID` (`NetworkID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`DeviceStatusExt`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DeviceStatusExt` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DeviceStatusExt` (
  `ID` VARCHAR(50) NOT NULL COMMENT 'extended device id',
  `Name` VARCHAR(50) NOT NULL COMMENT 'status name',
  `MainID` VARCHAR(50) NOT NULL COMMENT 'main device id',
  `Status` VARCHAR(1024) NOT NULL DEFAULT '{}' COMMENT 'extened device\'s status, json format',
  `UpdateAt` DATETIME NOT NULL,
  UNIQUE INDEX `DeviceStatusExtUni` (`MainID` ASC, `Name` ASC),
  INDEX `DeviceStatusExtIdx` (`MainID` ASC, `ID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`Players`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`Players` ;

CREATE TABLE IF NOT EXISTS `nccs`.`Players` (
  `PlayerID` VARCHAR(50) NOT NULL,
  `PlayerName` VARBINARY(32) NULL DEFAULT NULL,
  `PlayerType` TINYINT(4) NULL DEFAULT NULL COMMENT '0: celt audio player\n8: vlc player',
  `Priority` TINYINT(4) NULL DEFAULT '10',
  `Remark` VARBINARY(96) NULL DEFAULT NULL,
  `SchoolID` INT(11) NOT NULL DEFAULT '0',
  `RtmpURL` VARCHAR(255) NOT NULL DEFAULT '',
  `ShareInfo` varchar(1024) NOT NULL DEFAULT '',
  PRIMARY KEY (`PlayerID`),
  UNIQUE INDEX `ID_UNIQUE` (`PlayerID` ASC),
  INDEX `schoolIndex` USING BTREE (`SchoolID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`Users`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`Users` ;

CREATE TABLE IF NOT EXISTS `nccs`.`Users` (
    `User_ID` int(11) NOT NULL AUTO_INCREMENT,
    `User_Name` varchar(255) DEFAULT NULL,
    `User_Desc` varchar(255) NOT NULL DEFAULT '' COMMENT '用户登录名',
    `Pass_Word` varchar(255) NOT NULL DEFAULT '' COMMENT 'password, encode with PASSWORD()',
    `UsbKey` varchar(50) DEFAULT NULL COMMENT 'when the user''s authorization is expired.',
    `Priority` int(11) NOT NULL DEFAULT '100' COMMENT '用户优先级 值越小。优先级越高',
    `IsSuper` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否是超级管理员',
    `privilege` int(11) NOT NULL DEFAULT '0' COMMENT 'Bit 0: privilege of device control.\nBit1~Bit7: Reservered\n\nBit 8: privilege of creating audio and vedio broadcast tasks.\nBit9~Bit15: Reservered\n',
    `PrivilegeList` varchar(4096) NOT NULL DEFAULT '' COMMENT '用户权限列表',
    `IcCard` varchar(50) DEFAULT NULL,
    `Phone` varchar(50) DEFAULT NULL,
    `ServerSync` tinyint(4) NOT NULL DEFAULT '1' COMMENT 'Flag for sync data to cloud server, set when data is inserted or updated, clear after the changed data sysnc to cloud server.',
    `User_Type` tinyint(4) NOT NULL DEFAULT '2' COMMENT '用户类型：\n1：学生\n2：教师\n3：临时人员 \n4：学校管理员 \n5：平台管理员',
    `User_Sn` varchar(20) DEFAULT NULL COMMENT '学号或工号',
    `User_Expiry` datetime DEFAULT NULL COMMENT '有效期\nUser_Type=3时需要检查用户过期时间\n时间为0表示不过期',
    `Mgr_Privilege` tinyint(1) NOT NULL DEFAULT '0' COMMENT '设备管理权限标志\n0：具有部分权限，需要查询UserDevices表\n1：具有全部权限，无需查询UserDevices表',
    `Dev_Privilege` tinyint(1) NOT NULL DEFAULT '0' COMMENT '设备使用权限标志\n0：具有部分权限，需要查询UserDevices表\n1：具有全部权限，无需查询UserDevices表',
    `Create_Type` tinyint(1) NOT NULL DEFAULT '0' COMMENT '用户创建类型\n0：手动创建\n1：自动(IC卡同步)创建\n',
    `IC_Status` tinyint(1) NOT NULL DEFAULT '0' COMMENT 'IC卡状态\n0：IC卡正常\n1：IC卡挂失',
    `Dpm_Sn` varchar(20) NOT NULL DEFAULT '' COMMENT '部门编号',
    `Dpm_Name` varchar(100) NOT NULL DEFAULT '' COMMENT '部门名称',
    `Del_Flag` tinyint(1) NOT NULL DEFAULT '0' COMMENT 'delete flag:\n0: normal\n1: deleted',
    `UnionId` varchar(64) DEFAULT NULL,
    `SchoolID` int(11) NOT NULL DEFAULT '0',
    `UpdatePwdTime` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '密码更新时间。初始化时间为当前时间',
  PRIMARY KEY (`User_ID`),
  UNIQUE INDEX `UsbKey_UNIQUE` (`UsbKey` ASC),
  UNIQUE INDEX `User_Name_UNIQUE` (`User_Name` ASC),
  UNIQUE INDEX `IcCard_UNIQUE` (`SchoolID` ASC,`IcCard` ASC),
  UNIQUE INDEX `User_Sn_UNIQUE` (`SchoolID` ASC,`User_Sn` ASC),
  UNIQUE INDEX `Phone_UNIQUE` (`SchoolID` ASC,`Phone` ASC),
  UNIQUE INDEX `UnionId_uni` (`UnionId` ASC),
  INDEX `schoolIndex` USING BTREE (`SchoolID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- --------------------------------------------
-- Table structure for `nccs`.`DoubleClass`
-- --------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DoubleClass`;
CREATE TABLE `nccs`.`DoubleClass` (
  `ClassId` int(11) NOT NULL AUTO_INCREMENT COMMENT '课堂ID',
  `ClassName` varchar(255) NOT NULL DEFAULT '' COMMENT '课堂名称',
  `ExecTime` enum('WeekLoop','FixedTime') NOT NULL DEFAULT 'FixedTime' COMMENT 'WeekLoop - 按周循环  FixedTime - 固定时间',
  `FixStime` bigint(20) NOT NULL DEFAULT '0' COMMENT '固定时间 - 开始时间',
  `FixEtime` bigint(20) NOT NULL DEFAULT '0' COMMENT '固定时间 - 结束时间',
  `WeekStime` time NOT NULL COMMENT '按周循环 - 开始时间',
  `WeekEtime` time NOT NULL COMMENT '按周循环 - 结束时间',
  `WeekDays` varchar(255) NOT NULL DEFAULT '' COMMENT '0-6 对应 星期一 到 星期天 (英文逗号分隔,结束都加英文逗号)',
  `Valid` tinyint(4) NOT NULL DEFAULT '1' COMMENT '是否有效 1-有效 0-无效',
  `ConfigMd5` varchar(255) NOT NULL DEFAULT '' COMMENT '配置MD5',
  `SchoolId` int(11) NOT NULL DEFAULT '0' COMMENT '学校ID',
  `AddTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '添加时间',
  `ModTIme` bigint(20) NOT NULL DEFAULT '0' COMMENT '修改时间',
  `NextStime` bigint(20) NOT NULL DEFAULT '0' COMMENT '下次开始时间',
  `NextEtime` bigint(20) NOT NULL DEFAULT '0' COMMENT '下次结束时间',
  `CourseId` int(11) NOT NULL DEFAULT '0' COMMENT '双师课堂课程ID',
  `CourseTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '上课时间',
  `CourseStatus` enum('free','active','stop','fault') NOT NULL DEFAULT 'free' COMMENT '上课状态（无课-free  上课-active  停止-stop  故障-fault）',
  `CourseFault` varchar(1024) NOT NULL DEFAULT '' COMMENT '课程故障原因',
  PRIMARY KEY (`ClassId`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='双师课堂列表';


-- -----------------------------------------------
-- Table structure for `nccs`.`DoubleClassDevice`
-- -----------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DoubleClassDevice`;
CREATE TABLE `nccs`.`DoubleClassDevice` (
  `Id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
  `ClassId` int(11) NOT NULL DEFAULT '0' COMMENT '双师课堂ID',
  `DevId` varchar(50) NOT NULL DEFAULT '' COMMENT '设备ID',
  `ClassType` enum('lead','follow') NOT NULL DEFAULT 'lead' COMMENT '教室类型（lead - 主讲教室  follow - 辅讲教室）',
  `DeviceType` enum('main','slave') NOT NULL DEFAULT 'main' COMMENT '设备类型（main - 主控设备  slave - 从设备）',
  `Ip` varchar(255) NOT NULL DEFAULT '' COMMENT '设备IP地址',
  `CmdConfig` tinyint(4) NOT NULL DEFAULT '0' COMMENT '0-未发送配置命令 1-已发送配置命令',
  `CmdConfigTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '发送配置命令时间',
  PRIMARY KEY (`Id`),
  UNIQUE KEY `ClassDev` (`ClassId`,`DevId`),
  KEY `ClassId` (`ClassId`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='双师课堂设备';


-- ----------------------------------------------
-- Table structure for `nccs`.`DoubleClassCourse`
-- ----------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DoubleClassCourse`;
CREATE TABLE `nccs`.`DoubleClassCourse` (
  `CourseId` int(11) NOT NULL AUTO_INCREMENT COMMENT '课程ID',
  `SchoolIds` varchar(255) NOT NULL DEFAULT '' COMMENT '上课学校ID集合',
  `ClassId` int(11) NOT NULL DEFAULT '0' COMMENT '双师课堂ID',
  `ClassName` varchar(255) NOT NULL DEFAULT '' COMMENT '课堂名称',
  `ExecTime` enum('WeekLoop','FixedTime') NOT NULL DEFAULT 'FixedTime' COMMENT '执行时间',
  `FixStime` bigint(20) NOT NULL DEFAULT '0' COMMENT '固定时间-开始时间',
  `FixEtime` bigint(20) NOT NULL DEFAULT '0' COMMENT '固定时间 - 结束时间',
  `WeekStime` time NOT NULL COMMENT '按周循环-开始时间',
  `WeekEtime` time NOT NULL COMMENT '按周循环-结束时间',
  `WeekDays` varchar(255) NOT NULL DEFAULT '' COMMENT '0-6 对应 星期一 到 星期天 (英文逗号分隔,结束加英文逗号)',
  `CourseStime` bigint(20) NOT NULL DEFAULT '0' COMMENT '课程开始时间',
  `CourseEtime` bigint(20) NOT NULL DEFAULT '0' COMMENT '课程结束时间',
  `AddTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '添加时间',
  `CmdStartNums` int(11) NOT NULL DEFAULT '0' COMMENT '开始命令发送次数',
  `CmdStartTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '开始命令发送时间',
  `CourseStarted` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否上报已启动 0-未启动 1-已启动',
  `CmdEndNums` int(11) NOT NULL DEFAULT '0' COMMENT '结束命令发送次数',
  `CmdEndTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '结束命令发送时间',
  `CourseEnded` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否上报已结束 0-未上报 1-已上报',
  `ManualStopTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '手动停止时间',
  `CourseStatus` enum('creat','active','stop','fault','end') NOT NULL DEFAULT 'creat' COMMENT '课程状态（生成-creat  上课-active  停止-stop  故障-fault 结束-end）',
  `CourseFault` varchar(1024) NOT NULL DEFAULT '' COMMENT '故障原因',
  `ModTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '最后修改时间',
  PRIMARY KEY (`CourseId`),
  KEY `ClassId` (`ClassId`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='双师课堂课程（定时生成）';


-- ----------------------------------------------------
-- Table structure for `nccs`.`DoubleClassCourseDevice`
-- ----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DoubleClassCourseDevice`;
CREATE TABLE `nccs`.`DoubleClassCourseDevice` (
  `Id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'ID',
  `ClassId` int(11) NOT NULL DEFAULT '0' COMMENT '双师课堂ID',
  `CourseId` int(11) NOT NULL DEFAULT '0' COMMENT '双师课堂课程ID',
  `DevId` varchar(255) NOT NULL DEFAULT '' COMMENT '设备ID',
  `ClassType` enum('lead','follow') NOT NULL DEFAULT 'lead' COMMENT '教室类型（lead - 主讲教室  follow - 辅讲教室）',
  `DeviceType` enum('main','slave') NOT NULL DEFAULT 'main' COMMENT '设备类型（main - 主控设备  slave - 从设备）',
  `CmdStart` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否发送启动命令 0-未发送 1-已发送',
  `CmdStartTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '发送启动命令时间',
  `CmdStartNums` int(11) NOT NULL DEFAULT '0' COMMENT '发送启动命令次数',
  `CmdStartReport` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否上报处于双师课堂 0-未处于 1-已处于',
  `CmdStartReportTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '设备上报处于双师课堂时间',
  `CmdEnd` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否发送停止命令 0-未发送 1-已发送',
  `CmdEndTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '发送停止命令时间',
  `CmdEndNums` int(11) NOT NULL DEFAULT '0' COMMENT '发送停止命令次数',
  `CmdEndReport` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否上报不处于双师课堂 0-未上报 1-已上报',
  `CmdEndReportTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '设备上报不处于双师课堂时间',
  PRIMARY KEY (`Id`),
  UNIQUE KEY `CourseDev` (`CourseId`,`DevId`),
  KEY `ClassId` (`ClassId`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='双师课堂课程设备';


-- ------------------------------------------
-- Table structure for `nccs`.`DoubleClassLog`
-- ------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DoubleClassLog`;
CREATE TABLE `nccs`.`DoubleClassLog` (
  `Id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT 'ID',
  `ClassId` int(11) NOT NULL DEFAULT '0' COMMENT '双师课堂ID',
  `CourseId` int(11) NOT NULL DEFAULT '0' COMMENT '双师课堂课程ID',
  `DevId` varchar(255) NOT NULL DEFAULT '' COMMENT '设备ID',
  `Title` varchar(255) NOT NULL DEFAULT '' COMMENT '事件标题',
  `Detail` varchar(4096) NOT NULL DEFAULT '' COMMENT '详细数据',
  `AddTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '添加时间',
  PRIMARY KEY (`Id`),
  KEY `CourseId` (`CourseId`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='双师课堂运行详细日志';


-- -----------------------------------------------------
-- Table `nccs`.`TaskTemplate`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`TaskTemplate` ;

CREATE TABLE IF NOT EXISTS `nccs`.`TaskTemplate` (
  `idTaskTemplate` INT(11) NOT NULL AUTO_INCREMENT,
  `TemplateName` VARCHAR(50) NOT NULL DEFAULT '',
  `Enabled` TINYINT(4) NOT NULL DEFAULT '0',
  `SchoolID` INT(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`idTaskTemplate`),
  INDEX `schoolIndex` USING BTREE (`SchoolID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`PlaySessions`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlaySessions` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlaySessions` (
  `SessionID` SMALLINT(6) UNSIGNED NOT NULL DEFAULT '0',
  `SessionName` VARCHAR(50) NOT NULL,
  `SessionType` TINYINT(4) NULL DEFAULT NULL COMMENT '0: automatic broadcast task\n1: player created task\n2: manually played task\n10:BW803 player created task',
  `Priority` TINYINT(4) NULL DEFAULT NULL,
  `Status` TINYINT(4) NOT NULL DEFAULT '0',
  `CircleLength` INT(11) NOT NULL DEFAULT '0',
  `ClassID` INT(11) NULL DEFAULT NULL,
  `PlayerID` VARCHAR(50) NULL DEFAULT NULL,
  `Parent` SMALLINT(5) UNSIGNED NULL DEFAULT NULL,
  `BrdMode` INT(11) NULL DEFAULT NULL,
  `MemberMode` TINYINT(1) NOT NULL DEFAULT '0',
  `StreamType` TINYINT(4) UNSIGNED NOT NULL DEFAULT '1' COMMENT 'Stream Type: \n1: valid 0: invalid\nBit 0: audio\nBit1: Video',
  `SysEnabled` TINYINT(4) NULL DEFAULT NULL,
  `RfDevCtrl` BINARY(16) NULL DEFAULT NULL,
  `Owner` INT(11) NULL DEFAULT NULL,
  `PlayMode` TINYINT(4) NULL DEFAULT '0' COMMENT '0: Sequential Playing',
  `AudioGain` TINYINT(4) NULL DEFAULT '0',
  `Template` INT(11) NULL DEFAULT NULL,
  `SchoolID` INT(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`SessionID`),
  UNIQUE INDEX `SessionID_UNIQUE` (`SessionID` ASC),
  INDEX `Players` (`PlayerID` ASC),
  INDEX `SessionParent` (`Parent` ASC),
  INDEX `SessionMode` (`BrdMode` ASC),
  INDEX `SessionUser` (`Owner` ASC),
  INDEX `TaskTemplate_idx` (`Template` ASC),
  INDEX `schoolIndex` USING BTREE (`SchoolID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`PlaySessionTime`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlaySessionTime` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlaySessionTime` (
  `ScheduleID` INT(11) NOT NULL AUTO_INCREMENT,
  `SessionID` SMALLINT(6) UNSIGNED NOT NULL,
  `WeekDay` TINYINT(4) NOT NULL,
  `PlayTime` DATETIME NOT NULL,
  `TempFlag` TINYINT(4) NULL DEFAULT NULL,
  `Length` INT(11) NULL DEFAULT NULL,
  `EntryID` INT(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`ScheduleID`),
  UNIQUE INDEX `SesTime_UNIQUE` (`SessionID` ASC, `WeekDay` ASC, `PlayTime` ASC),
  INDEX `Schsessionid` (`SessionID` ASC),
  CONSTRAINT `sIDForeignKey`
    FOREIGN KEY (`SessionID`)
    REFERENCES `nccs`.`PlaySessions` (`SessionID`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COMMENT = 'Auto broadcast playing schedules';


-- -----------------------------------------------------
-- Table `nccs`.`DisableDevSession`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`DisableDevSession` ;

CREATE TABLE IF NOT EXISTS `nccs`.`DisableDevSession` (
  `ScheduleID` INT(11) NOT NULL,
  `DeviceID` VARCHAR(50) NOT NULL,
  `Disabled` TINYINT(4) NULL DEFAULT NULL,
  PRIMARY KEY (`ScheduleID`, `DeviceID`),
  INDEX `DisDevShedule` (`ScheduleID` ASC),
  INDEX `DisabledScheDevice` (`DeviceID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`EventModel`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`EventModel` ;

CREATE TABLE IF NOT EXISTS `nccs`.`EventModel` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `Manufacturer` VARCHAR(31) NOT NULL,
  `Model` VARCHAR(31) NOT NULL,
  `Magic` INT(11) UNSIGNED NOT NULL,
  `SchoolID` INT(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  INDEX `schoolIndex` USING BTREE (`SchoolID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`Event`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`Event` ;

CREATE TABLE IF NOT EXISTS `nccs`.`Event` (
  `Id` INT(11) NOT NULL AUTO_INCREMENT,
  `Name` VARCHAR(31) NOT NULL,
  `StartTask` SMALLINT(6) UNSIGNED NULL DEFAULT NULL,
  `EndTask` SMALLINT(6) UNSIGNED NULL DEFAULT NULL,
  `Config` VARBINARY(64) NOT NULL COMMENT '事件配置',
  `Model` INT(11) NOT NULL COMMENT '型号',
  `Version` INT(11) NOT NULL DEFAULT '0' COMMENT '版本号:自动生成，前端禁止操作',
  `SchoolID` INT(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`Id`),
  INDEX `model_idx` (`Model` ASC),
  INDEX `event_end_fkn_idx` (`EndTask` ASC),
  INDEX `event_start_fkn_idx` (`StartTask` ASC),
  INDEX `schoolIndex` USING BTREE (`SchoolID` ASC),
  CONSTRAINT `EventModel`
    FOREIGN KEY (`Model`)
    REFERENCES `nccs`.`EventModel` (`id`),
  CONSTRAINT `event_end_fkn`
    FOREIGN KEY (`EndTask`)
    REFERENCES `nccs`.`PlaySessions` (`SessionID`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION,
  CONSTRAINT `event_start_fkn`
    FOREIGN KEY (`StartTask`)
    REFERENCES `nccs`.`PlaySessions` (`SessionID`)
    ON DELETE SET NULL
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`GroupCtrlSchedule`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`GroupCtrlSchedule` ;

CREATE TABLE IF NOT EXISTS `nccs`.`GroupCtrlSchedule` (
  `ScheduleID` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
  `GroupID` INT(11) NOT NULL,
  `ActionTime` TIME NOT NULL,
  `Action` INT(11) NULL DEFAULT NULL,
  `WeekDay` TINYINT(4) NOT NULL,
  `State` INT(11) NULL DEFAULT '0',
  `ExtArgs` VARCHAR(256) NULL DEFAULT NULL,
  `Disable` TINYINT(1) NULL DEFAULT '0',
  PRIMARY KEY (`GroupID`, `ActionTime`, `WeekDay`),
  UNIQUE INDEX `ScheduleID_UNIQUE` (`ScheduleID` ASC),
  INDEX `DeviD` (`GroupID` ASC),
  INDEX `DeviceID` (`GroupID` ASC),
  INDEX `DevCtrlGroupID` (`GroupID` ASC),
  CONSTRAINT `DevCtrlGroupID`
    FOREIGN KEY (`GroupID`)
    REFERENCES `nccs`.`DevClasses` (`ClassID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`IpCall`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`IpCall` ;

CREATE TABLE IF NOT EXISTS `nccs`.`IpCall` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `device` VARCHAR(45) NULL DEFAULT NULL COMMENT 'device id',
  `waiter` INT(11) NULL DEFAULT NULL,
  `audioPort` INT(11) NULL DEFAULT NULL,
  `ringing` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP,
  `status` ENUM('ringing', 'talking', 'idle') NULL DEFAULT 'ringing',
  `direction` ENUM('b2s', 'd2s') NULL DEFAULT 'b2s',
  `webrtcUpdate` TIMESTAMP NULL DEFAULT NULL,
  `webrtcStatus` ENUM('running', 'error', 'ready', 'idle') NULL DEFAULT 'idle',
  `wsPort` INT(11) NULL DEFAULT NULL COMMENT 'websocket listen port',
  `listen` TINYINT(4) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`),
  UNIQUE INDEX `port_unique` (`audioPort` ASC),
  UNIQUE INDEX `webrtcPort_UNIQUE` (`wsPort` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`IpCameraRtmp`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`IpCameraRtmp` ;

CREATE TABLE IF NOT EXISTS `nccs`.`IpCameraRtmp` (
  `name` VARCHAR(128) NULL DEFAULT NULL COMMENT 'key经md5生成',
  `key` VARCHAR(45) NOT NULL COMMENT 'rtmp节目key值，由摄像头Ip/端口/通道/主副码(main或sub)',
  `pushId` INT(11) NOT NULL DEFAULT '-1' COMMENT 'ffmpeg推流ID',
  `pullCnt` INT(11) NOT NULL DEFAULT '0' COMMENT 'rtmp拉流计数',
  `updateAt` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`key`),
  UNIQUE INDEX `key_UNIQUE` (`key` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`LastProcessedTime`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`LastProcessedTime` ;

CREATE TABLE IF NOT EXISTS `nccs`.`LastProcessedTime` (
  `LastTimeID` INT(11) NOT NULL DEFAULT '1' COMMENT 'Only one record in this table',
  `LastTime` DATETIME NULL DEFAULT NULL,
  PRIMARY KEY (`LastTimeID`))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8
COMMENT = 'a globe time which record last timer process time.';


-- -----------------------------------------------------
-- Table `nccs`.`MediaFiles`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`MediaFiles` ;

CREATE TABLE IF NOT EXISTS `nccs`.`MediaFiles` (
  `MediaID` INT(11) NOT NULL AUTO_INCREMENT,
  `FileName` VARCHAR(64) NULL DEFAULT NULL,
  `FileSize` BIGINT(20) NULL DEFAULT NULL,
  `TotalTime` INT(11) NOT NULL DEFAULT '0',
  `FileFmt` INT(11) NULL DEFAULT NULL COMMENT '0: celt\n1: mp3\n2: ts\n3: mp4, mov',
  `BitRate` INT(11) NULL DEFAULT NULL,
  `VedioCodec` INT(11) NULL DEFAULT NULL COMMENT '0: h264\n1: mpeg4',
  `Height` INT(11) NULL DEFAULT NULL,
  `Width` INT(11) NULL DEFAULT NULL,
  `FrameRate` INT(11) NULL DEFAULT NULL,
  `AudioCodec` INT(11) NULL DEFAULT NULL COMMENT '0: celt\n1: mp3',
  `Channels` INT(11) NULL DEFAULT NULL,
  `SampleRate` INT(11) NULL DEFAULT NULL,
  `Parent` INT(11) NULL DEFAULT NULL,
  `Gain` TINYINT(4) NULL DEFAULT '0',
  `CreateTime` DATETIME NULL DEFAULT NULL,
  `FilePath` VARCHAR(256) NULL DEFAULT NULL,
  `Owner` INT(11) NULL DEFAULT NULL COMMENT 'sysfolder owner',
  `Sysfolder` TINYINT(4) NULL DEFAULT NULL COMMENT 'system create folder,not update or delete\n1:true',
  `Check` TINYINT(4) NOT NULL DEFAULT '0',
  `SchoolID` INT(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`MediaID`),
  UNIQUE INDEX `ID_UNIQUE` (`MediaID` ASC),
  INDEX `MediaParent` (`Parent` ASC),
  INDEX `MediaUser_idx` (`Owner` ASC),
  INDEX `schoolIndex` USING BTREE (`SchoolID` ASC),
  CONSTRAINT `MediaParent`
    FOREIGN KEY (`Parent`)
    REFERENCES `nccs`.`MediaFiles` (`MediaID`)
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`Messages`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`Messages` ;

CREATE TABLE IF NOT EXISTS `nccs`.`Messages` (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `MsgFrom` TINYINT(4) NOT NULL,
  `MsgTo` TINYINT(4) NOT NULL,
  `MsgType` TINYINT(4) NULL DEFAULT NULL,
  `MsgTime` DATETIME NULL DEFAULT NULL,
  `CmdType` INT(11) NULL DEFAULT NULL,
  `CmdObjType` INT(11) NULL DEFAULT NULL,
  `CmdObjID` VARCHAR(50) NULL DEFAULT NULL,
  `CmdObjIP` VARCHAR(50) NULL DEFAULT NULL,
  PRIMARY KEY (`ID`),
  UNIQUE INDEX `ID_UNIQUE` (`ID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`MsgTasks`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`MsgTasks` ;

CREATE TABLE IF NOT EXISTS `nccs`.`MsgTasks` (
  `MsgTaskID` INT(11) NOT NULL,
  `PlayedTime` DATETIME NULL DEFAULT NULL,
  `TimeStyle` INT(11) NULL DEFAULT NULL COMMENT '0: Play one time.\n    played on PlayedTime.\nother: repeat weekly',
  `Duration` INT(11) NULL DEFAULT NULL,
  `Content` VARCHAR(256) NULL DEFAULT NULL,
  PRIMARY KEY (`MsgTaskID`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`MsgTaskDev`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`MsgTaskDev` ;

CREATE TABLE IF NOT EXISTS `nccs`.`MsgTaskDev` (
  `MsgTaskID` INT(11) NOT NULL,
  `DevID` VARCHAR(45) NOT NULL,
  PRIMARY KEY (`MsgTaskID`, `DevID`),
  INDEX `msgtask` (`MsgTaskID` ASC),
  INDEX `msgtaskdev` (`DevID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`NotificationMsg`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`NotificationMsg` ;

CREATE TABLE IF NOT EXISTS `nccs`.`NotificationMsg` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `uid` INT(11) NOT NULL COMMENT '用户ID',
  `type` VARCHAR(32) NOT NULL COMMENT '事件类型',
  `time` DATETIME NULL DEFAULT NULL COMMENT '消息推送的时间',
  `ipaddress` VARCHAR(45) NULL DEFAULT NULL COMMENT '消息推送的ip地址',
  `description` VARCHAR(4096) NOT NULL COMMENT '推送的具体消息内容.',
  `update_at` DATETIME NULL DEFAULT NULL,
  `handle_uid` INT(11) NULL DEFAULT NULL,
  `status` ENUM('PENDING', 'RESOLVED', 'REJECTED') NOT NULL DEFAULT 'PENDING',
  PRIMARY KEY (`id`),
  UNIQUE INDEX `id_UNIQUE` (`id` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8mb4;


-- -----------------------------------------------------
-- Table `nccs`.`PlayListFiles`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlayListFiles` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlayListFiles` (
  `PlayListFIleId` INT(11) NOT NULL AUTO_INCREMENT,
  `FileID` INT(11) NULL DEFAULT NULL,
  `SequenceID` INT(11) NOT NULL,
  `SessionID` SMALLINT(6) UNSIGNED NOT NULL,
  `Duration` INT(11) NULL DEFAULT '0',
  `KeyIndex` INT(11) NULL DEFAULT NULL,
  `PlayerID` VARCHAR(50) NULL DEFAULT NULL,
  PRIMARY KEY (`PlayListFIleId`),
  UNIQUE INDEX `SessionIDSeq` (`SessionID` ASC, `SequenceID` ASC),
  INDEX `SessionID` (`SessionID` ASC),
  INDEX `FileID` (`FileID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`PlayerAlive`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlayerAlive` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlayerAlive` (
  `PlayerID` VARCHAR(50) NOT NULL,
  `RefreshTime` DATETIME NULL DEFAULT NULL,
  PRIMARY KEY (`PlayerID`),
  INDEX `PlayerActivePlayerID` (`PlayerID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`PlayerKeys`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlayerKeys` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlayerKeys` (
  `PlayerKeyId` INT(11) NOT NULL AUTO_INCREMENT,
  `PlayerID` VARCHAR(50) NOT NULL,
  `Index` INT(11) NOT NULL,
  `GroupDisable` TINYINT(4) NULL DEFAULT '0',
  `DevDisable` TINYINT(4) NULL DEFAULT '0',
  `GroupID` INT(11) NULL DEFAULT NULL,
  `logic_class` INT(1) NOT NULL DEFAULT '0',
  `logic_class_id` INT(11) NULL DEFAULT NULL,
  `name` varchar(255) NOT NULL DEFAULT "",
  PRIMARY KEY (`PlayerKeyId`),
  UNIQUE INDEX `PlayerIndex` (`PlayerID` ASC, `Index` ASC),
  INDEX `PlayerKey_PlayerID` (`PlayerID` ASC),
  INDEX `PlayerGroupID` (`GroupID` ASC),
  CONSTRAINT `PlayerGroupID`
    FOREIGN KEY (`GroupID`)
    REFERENCES `nccs`.`DevClasses` (`ClassID`)
    ON DELETE SET NULL
    ON UPDATE SET NULL,
  CONSTRAINT `PlayerKey_PlayerID`
    FOREIGN KEY (`PlayerID`)
    REFERENCES `nccs`.`Players` (`PlayerID`),
  CONSTRAINT `PlayerLogicClassID`
    FOREIGN KEY (`logic_class_id`)
    REFERENCES `nccs`.`LogicClasses` (`id`)
    ON DELETE SET NULL
    ON UPDATE SET NULL)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`PlayerStatus`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlayerStatus` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlayerStatus` (
  `PlayerID` VARCHAR(50) NOT NULL,
  `SessionID` SMALLINT(5) UNSIGNED NULL DEFAULT '0',
  `ScheduleID` INT(11) NULL DEFAULT NULL,
  `IpAddress` VARCHAR(50) NULL DEFAULT NULL,
  `NetID` TINYINT(4) NULL DEFAULT NULL,
  `ActualSesID` INT(11) NULL DEFAULT NULL,
  `PlayPort` INT(11) NULL DEFAULT NULL,
  `PlayType` TINYINT(4) NULL DEFAULT NULL,
  `SchoolID` INT(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`PlayerID`),
  INDEX `PlayerStatusPlayerID` (`PlayerID` ASC),
  INDEX `PlayerStatusSessionID` (`SessionID` ASC),
  INDEX `PlayerStatusScheduleID` (`ScheduleID` ASC),
  INDEX `schoolIndex` USING BTREE (`SchoolID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`PlayingSessions`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PlayingSessions` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PlayingSessions` (
  `SessionID` SMALLINT(6) UNSIGNED NOT NULL,
  `PlayerID` VARCHAR(50) NULL DEFAULT NULL,
  `PlayingFileID` INT(11) NULL DEFAULT NULL,
  `MultiPort` INT(11) NULL DEFAULT NULL,
  `CircleLength` INT(11) NULL DEFAULT NULL,
  `CurrFileProgress` INT(11) NULL DEFAULT NULL,
  `CurrTotalProgress` INT(11) NULL DEFAULT NULL,
  `Priority` TINYINT(4) NULL DEFAULT NULL,
  `Pause` TINYINT(4) NOT NULL DEFAULT '0',
  `ScheduleID` INT(11) NULL DEFAULT NULL,
  `BrdMode` INT(11) NULL DEFAULT NULL,
  `SesType` TINYINT(4) NULL DEFAULT '0',
  `StreamType` TINYINT(4) UNSIGNED NULL DEFAULT '1',
  `PlayBeginTime` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`SessionID`),
  UNIQUE INDEX `SessionID_UNIQUE` (`SessionID` ASC),
  UNIQUE INDEX `PlayerID_UNIQUE` (`PlayerID` ASC),
  INDEX `Session` (`SessionID` ASC))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`ProjectorType`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`ProjectorType` ;

CREATE TABLE IF NOT EXISTS `nccs`.`ProjectorType` (
  `Type` VARCHAR(50) NOT NULL,
  `PoweroffDelay` INT(11) NOT NULL,
  `CheckBit` INT(11) NOT NULL,
  `StopBit` INT(11) NOT NULL,
  `DataBit` INT(11) NOT NULL,
  `BaudRate` INT(11) NOT NULL,
  `CmdOpen` VARCHAR(255) NOT NULL,
  `CmdClose` VARCHAR(255) NOT NULL,
  `CmdFromPc` VARCHAR(255) NOT NULL,
  `CmdFromVideo` VARCHAR(255) NOT NULL,
  `CmdChannel3` varchar(255) NOT NULL DEFAULT '',
  `CmdChannel4` varchar(255) NOT NULL DEFAULT '',
  `ChangedFromLocal` tinyint(1) NOT NULL DEFAULT 0 COMMENT '值为1时表示投影机是否被用户在本地服务器修改过(本地添加的型号和本地修改过的投影机型号)',
  PRIMARY KEY (`Type`),
  UNIQUE INDEX `Type_UNIQUE` (`Type` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`PwrDisplaySet`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PwrDisplaySet` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PwrDisplaySet` (
  `PwrID` TINYINT(4) NOT NULL,
  `Name` VARCHAR(45) NULL DEFAULT NULL,
  `Type` TINYINT(4) NULL DEFAULT NULL,
  `Icon` VARCHAR(64) NULL DEFAULT NULL,
  `SchoolID` INT(11) NOT NULL DEFAULT '0',
  INDEX `schoolIndex`(`SchoolID`) USING BTREE,
  UNIQUE INDEX `uniqueIndex` USING BTREE (`PwrID` ASC, `SchoolID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`Scene`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`Scene` ;

CREATE TABLE IF NOT EXISTS `nccs`.`Scene` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `SchoolID` INT(11) NOT NULL DEFAULT '0',
  `name` VARCHAR(45) NOT NULL DEFAULT '' COMMENT '名称',
  `icon` VARCHAR(45) NOT NULL DEFAULT '' COMMENT '图标',
  `control_list` VARCHAR(2048) NOT NULL DEFAULT '{}' COMMENT '操作清单',
  `product_match_preg` VARCHAR(128) NOT NULL DEFAULT '' COMMENT '产品匹配列表',
  PRIMARY KEY (`id`),
  INDEX `schoolIndex` USING BTREE (`SchoolID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COMMENT = '设备场景表';


-- -----------------------------------------------------
-- Table `nccs`.`SchoolInfo`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SchoolInfo` ;

CREATE TABLE IF NOT EXISTS `nccs`.`SchoolInfo` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(255) NOT NULL,
  `owner` INT(11) NOT NULL,
  `disable` smallint(2) NOT NULL DEFAULT '0',
  `logo_path` VARCHAR(255) NOT NULL DEFAULT '' COMMENT '学校logo路径',
  `data_visualization_name` VARCHAR(255) NOT NULL DEFAULT '' COMMENT '学校数据大屏名称',
  `update_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `create_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`SectionTable`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SectionTable` ;

CREATE TABLE IF NOT EXISTS `nccs`.`SectionTable` (
`id` INT(11) UNSIGNED NOT NULL AUTO_INCREMENT,
`zone` VARCHAR(32) NOT NULL,
`name` VARCHAR(32) NOT NULL DEFAULT '0' COMMENT '仅填写数字，表示第几节课。\n为保证兼容，未做类型变更',
`alias` VARCHAR(32) NOT NULL COMMENT '节次别名，如第一节',
`start` TIME NOT NULL DEFAULT '00:00:00',
`end` TIME NOT NULL DEFAULT '23:59:59',
`SchoolID` INT(11) NOT NULL DEFAULT '0',
PRIMARY KEY (`id`),
UNIQUE INDEX `SectionTableUnique` (`zone` ASC, `name` ASC, `SchoolID` ASC),
INDEX `SectionTableIndex` (`name` ASC, `zone` ASC),
INDEX `schoolIndex` USING BTREE (`SchoolID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`SensorProduct`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SensorProduct` ;

CREATE TABLE IF NOT EXISTS `nccs`.`SensorProduct` (
  `product_id` INT(11) NOT NULL,
  `name` VARCHAR(64) NOT NULL,
  `mod_bus` SMALLINT(6) NOT NULL,
  `vendor_id` INT(11) NOT NULL,
  `update_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `create_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `from_cloud` tinyint(1) NOT NULL DEFAULT 0,
  UNIQUE INDEX `product_index` USING BTREE (`product_id` ASC, `vendor_id` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`SensorVendor`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SensorVendor` ;

CREATE TABLE IF NOT EXISTS `nccs`.`SensorVendor` (
  `id` INT(11) UNSIGNED NOT NULL,
  `name` VARCHAR(64) NOT NULL,
  `update_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `create_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `from_cloud` tinyint(1) NOT NULL DEFAULT 0,
  PRIMARY KEY (`id`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`SessionCtrlList`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SessionCtrlList` ;

CREATE TABLE IF NOT EXISTS `nccs`.`SessionCtrlList` (
  `id` INT(10) UNSIGNED NOT NULL AUTO_INCREMENT,
  `SessionID` SMALLINT(6) NOT NULL,
  `SubID` INT(11) NOT NULL,
  `State` INT(11) NULL DEFAULT NULL,
  `Action` INT(11) NULL DEFAULT NULL,
  `DataState` INT(1) NULL DEFAULT NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `SesSubID_UNIQUE` USING BTREE (`SessionID` ASC, `SubID` ASC),
  INDEX `SessionID` USING BTREE (`SessionID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`SessionDevice`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SessionDevice` ;

CREATE TABLE IF NOT EXISTS `nccs`.`SessionDevice` (
  `SessionDevID` INT(11) NOT NULL AUTO_INCREMENT,
  `DeviceID` VARCHAR(50) NOT NULL,
  `SessionID` SMALLINT(5) UNSIGNED NOT NULL,
  `KeyIndex` INT(11) NOT NULL DEFAULT '0',
  `DevDisabled` TINYINT(4) NULL DEFAULT '0',
  PRIMARY KEY (`SessionDevID`),
  UNIQUE INDEX `SessionDevKey` (`SessionID` ASC, `DeviceID` ASC, `KeyIndex` ASC),
  INDEX `SessionDevDev` (`DeviceID` ASC),
  INDEX `SessionDevSes` (`SessionID` ASC),
  CONSTRAINT `SessionDevDev`
    FOREIGN KEY (`DeviceID`)
    REFERENCES `nccs`.`DeviceList` (`DevID`)
    ON DELETE CASCADE,
  CONSTRAINT `SessionDevSes`
    FOREIGN KEY (`SessionID`)
    REFERENCES `nccs`.`PlaySessions` (`SessionID`)
    ON DELETE CASCADE)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`SrsServer`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SrsServer` ;

CREATE TABLE IF NOT EXISTS `nccs`.`SrsServer` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `name` VARCHAR(32) NOT NULL,
  `server` VARCHAR(128) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE INDEX `server_uni` (`server` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`SrsServerStatus`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SrsServerStatus` ;

CREATE TABLE IF NOT EXISTS `nccs`.`SrsServerStatus` (
  `id` INT(11) NOT NULL,
  `server` VARCHAR(128) NOT NULL,
  `count` INT(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`id`))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`SubNetwork`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SubNetwork` ;

CREATE TABLE IF NOT EXISTS `nccs`.`SubNetwork` (
  `idSubNetwork` INT(11) NOT NULL,
  `NetMask` VARCHAR(50) NULL DEFAULT NULL,
  `IpAddress` VARCHAR(50) NULL DEFAULT NULL,
  `SchoolID` INT(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`idSubNetwork`),
  UNIQUE INDEX `idSubNetwork_UNIQUE` (`idSubNetwork` ASC),
  INDEX `schoolIndex` USING BTREE (`SchoolID` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`SystemLog`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SystemLog` ;

CREATE TABLE IF NOT EXISTS `nccs`.`SystemLog` (
  `id` INT(11) NOT NULL AUTO_INCREMENT,
  `SchoolID` INT(11) NOT NULL DEFAULT '0',
  `at` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
  `ip` VARCHAR(16) NULL DEFAULT NULL,
  `result` INT(11) NOT NULL,
  `username` VARCHAR(255) NULL DEFAULT NULL,
  `title1` VARCHAR(255) NULL DEFAULT NULL,
  `title2` VARCHAR(255) NULL DEFAULT NULL,
  `type` VARCHAR(64) NOT NULL COMMENT 'controller name',
  `action` VARCHAR(64) NOT NULL COMMENT 'action name',
  `detail` VARCHAR(1024) NULL DEFAULT NULL,
  `parameter_detail` varchar(4096) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NULL DEFAULT NULL,
  PRIMARY KEY (`id`,`at`),
  INDEX `systemlog_idx` (`username` ASC, `type` ASC, `ip` ASC),
  INDEX `SchoolAt` USING BTREE (`SchoolID`,`at`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`Timetable`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`Timetable` ;

CREATE TABLE IF NOT EXISTS `nccs`.`Timetable` (
  `Id` INT(11) NOT NULL AUTO_INCREMENT,
  `DevId` VARCHAR(50) NOT NULL,
  `UserId` INT(11) NOT NULL,
  `WeekDay` TINYINT(4) NOT NULL,
  `Start` DATETIME NOT NULL DEFAULT '9999-12-31 23:59:59',
  `End` DATETIME NOT NULL DEFAULT '0000-01-01 00:00:00',
  `Type` ENUM('normal', 'temporary') NOT NULL DEFAULT 'normal' COMMENT 'normal:正课\ntemporary:临课',
  `OneTime` TINYINT(4) NOT NULL DEFAULT '0',
  `Sync` TINYINT(4) NOT NULL DEFAULT '0',
  `SchoolID` INT(11) NOT NULL DEFAULT '0',
  PRIMARY KEY (`Id`),
  UNIQUE INDEX `only` (`DevId` ASC, `UserId` ASC, `WeekDay` ASC, `Start` ASC, `End` ASC, `Type` ASC),
  INDEX `deviceId_idx` (`DevId` ASC),
  INDEX `table_idx` (`DevId` ASC, `UserId` ASC),
  INDEX `userIdKey_idx` (`UserId` ASC),
  INDEX `schoolIndex` USING BTREE (`SchoolID` ASC),
  CONSTRAINT `deviceIdKey`
    FOREIGN KEY (`DevId`)
    REFERENCES `nccs`.`DeviceList` (`DevID`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `userIdKey`
    FOREIGN KEY (`UserId`)
    REFERENCES `nccs`.`Users` (`User_ID`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COMMENT = '课表';


-- -----------------------------------------------------
-- Table `nccs`.`TimetableV1`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`TimetableV1` ;

CREATE TABLE IF NOT EXISTS `nccs`.`TimetableV1` (
  `ID` INT(11) NOT NULL AUTO_INCREMENT,
  `Dev_Name` VARCHAR(50) NOT NULL,
  `User_Flag` VARCHAR(20) NOT NULL DEFAULT '',
  `User_Name` VARCHAR(32) NOT NULL DEFAULT '' COMMENT '\"tmp_phone\"临时课需要填写用户姓名',
  `Zone` VARCHAR(32) NOT NULL DEFAULT '',
  `CourseName` VARCHAR(64) NOT NULL DEFAULT '',
  `TermName` VARCHAR(32) NOT NULL DEFAULT '',
  `SectionStart` INT(11) NOT NULL DEFAULT '0',
  `SectionEnd` INT(11) NOT NULL DEFAULT '0',
  `WeekStart` INT(11) NOT NULL DEFAULT '1',
  `WeekEnd` INT(11) NOT NULL DEFAULT '9999',
  `WeekDay` INT(11) NOT NULL DEFAULT '6',
  `WeekType` ENUM('single', 'double', 'all') NOT NULL DEFAULT 'all',
  `Active` ENUM('yes', 'no') NOT NULL DEFAULT 'yes' COMMENT '是否活动，活动状态的课表会用于设备控制',
  `Type` ENUM('normal', 'tmp_usersn', 'tmp_phone') NOT NULL DEFAULT 'normal' COMMENT 'normal: 正式课\ntmp_usersn:用户工号临时课\ntmp_phone:手机号临时课',
  PRIMARY KEY (`ID`),
  INDEX `TimetableV1_idx2` (`Dev_Name` ASC),
  INDEX `TimetableV1_idx1` (`User_Flag` ASC))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Table `nccs`.`UserDevices`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`UserDevices` ;

CREATE TABLE IF NOT EXISTS `nccs`.`UserDevices` (
  `UserDevID` INT(11) NOT NULL AUTO_INCREMENT,
  `UserID` INT(11) NOT NULL,
  `DevID` VARCHAR(50) NOT NULL,
  `Pri` TINYINT(1) NOT NULL DEFAULT '0' COMMENT 'bit0: 用户可以使用的设备\nbit1: 用户可以管理的设备',
  PRIMARY KEY (`UserDevID`),
  UNIQUE INDEX `UserDev` (`UserID` ASC, `DevID` ASC),
  INDEX `user_dev` (`DevID` ASC),
  INDEX `UserId` (`UserID` ASC),
  CONSTRAINT `UserId`
    FOREIGN KEY (`UserID`)
    REFERENCES `nccs`.`Users` (`User_ID`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION,
  CONSTRAINT `user_dev`
    FOREIGN KEY (`DevID`)
    REFERENCES `nccs`.`DeviceList` (`DevID`)
    ON DELETE CASCADE
    ON UPDATE NO ACTION)
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8;

-- ----------------------------
-- Table `nccs`.DeviceScenes
-- ----------------------------
DROP TABLE IF EXISTS `DeviceScenes`;
CREATE TABLE IF NOT EXISTS `nccs`.`DeviceScenes`  (
  `DeviceSceneID` int(11) NOT NULL AUTO_INCREMENT,
  `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '',
  `SceneID` int(11) NOT NULL,
  `SceneName` varchar(96) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '场景名称不能超过32个汉字',
  `SceneCtrlList` varchar(4096) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '场景控制列表，为json字符串',
  PRIMARY KEY (`DeviceSceneID`) USING BTREE,
  UNIQUE INDEX `device_scene`(`DeviceID`, `SceneID`) USING BTREE COMMENT '一个设备不能有两个相同id的场景'
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;



-- -----------------------------------------------------
-- Table `nccs`.`tmp_DelMediaFiles`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`tmp_DelMediaFiles` ;

CREATE TABLE IF NOT EXISTS `nccs`.`tmp_DelMediaFiles` (
  `filepath` VARCHAR(256) NOT NULL,
  PRIMARY KEY (`filepath`))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`tmp_result`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`tmp_result` ;

CREATE TABLE IF NOT EXISTS `nccs`.`tmp_result` (
  `idtmp_result` INT(11) NULL DEFAULT NULL)
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;


-- -----------------------------------------------------
-- Table `nccs`.`tmp_storage`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`tmp_storage` ;

CREATE TABLE IF NOT EXISTS `nccs`.`tmp_storage` (
  `key` VARCHAR(32) NOT NULL,
  `strv` VARCHAR(64) NULL DEFAULT NULL,
  `intv` INT(11) NULL DEFAULT NULL,
  `datev` DATETIME NULL DEFAULT NULL,
  `expire` INT(10) NULL DEFAULT NULL,
  PRIMARY KEY (`key`))
ENGINE = MEMORY
DEFAULT CHARACTER SET = utf8;

-- -----------------------------------------------------
-- Table `nccs`.`PcCallDirectories`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PcCallDirectories` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PcCallDirectories`  (
  `DirectoryID` int(10) NOT NULL AUTO_INCREMENT,
  `Name` varchar(63) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
  `SessionID` int(10) NOT NULL,
  `IsDefault` tinyint(1) NOT NULL,
  PRIMARY KEY (`DirectoryID`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

-- -----------------------------------------------------
-- Table `nccs`.`PcCallBindFiles`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`PcCallBindFiles` ;

CREATE TABLE IF NOT EXISTS `nccs`.`PcCallBindFiles`  (
  `BindID` int(10) NOT NULL AUTO_INCREMENT,
  `FileID` int(10) NOT NULL,
  `SessionID` int(10) NOT NULL,
  `Parent` int(10) NOT NULL,
  `OrderIndex` int(10) NOT NULL COMMENT '播放顺序',
  PRIMARY KEY (`BindID`) USING BTREE,
  UNIQUE INDEX `parent_file`(`FileID`, `Parent`) USING BTREE COMMENT '一个目录下面不出现两个一样的文件'
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

-- -----------------------------------------------------
-- Table `nccs`.`EnvironmentalParameters`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`EnvironmentalParameters` ;
CREATE TABLE IF NOT EXISTS `nccs`.`EnvironmentalParameters`  (
  `ID` int(10) NOT NULL AUTO_INCREMENT,
  `ProtocolFieldName` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '参数在协议中对应的字段',
  `Name` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '参数名称',
  `Unit` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '单位',
  `ExactValue` float(8, 3) UNSIGNED NOT NULL DEFAULT 1.000 COMMENT '精确度',
  `from_cloud` tinyint(1) NOT NULL DEFAULT 0,
  PRIMARY KEY (`ID`) USING BTREE,
  UNIQUE INDEX `protocolFieldName`(`ProtocolFieldName`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

-- -----------------------------------------------------
-- Table `nccs`.`EnvControlDevices`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`EnvControlDevices` ;
CREATE TABLE IF NOT EXISTS `nccs`.`EnvControlDevices`  (
  `ID` int(10) NOT NULL AUTO_INCREMENT,
  `EnvCtrlInfoID` int(10) NOT NULL,
  `DeviceID` varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
  PRIMARY KEY (`ID`) USING BTREE,
  UNIQUE INDEX `ctrlID_devID`(`EnvCtrlInfoID`, `DeviceID`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;


-- -----------------------------------------------------
-- Table `nccs`.`EnvControlInfo`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`EnvControlInfo` ;
CREATE TABLE `nccs`.`EnvControlInfo`  (
  `ID` int(10) NOT NULL AUTO_INCREMENT,
  `Type` int(10) NOT NULL COMMENT '策略类型。1：环境策略',
  `Name` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '策略的名称',
  `Conditions` varchar(4096) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '{}' COMMENT '策略条件。json格式',
  `Duration` int(10) NOT NULL COMMENT '满足条件以后需要持续该时间长度才执行任务',
  `Operation` varchar(4096) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL  DEFAULT '{}' COMMENT '该策略需要执行的操作。json格式',
  `Weekday` int(10) NOT NULL COMMENT '表示周几。bit1-bit6表示周一到周六，bit0表示周天',
  `EntryTimeType` int(10) NOT NULL COMMENT '生效时间类型 0：表示每天中哪个时间范围执行该策略 1：表示每天中哪个时间点执行该策略',
  `StartTime` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '与EndTime一起作用，比如：08:00:00 EntryTimeType = 0时有效',
  `EndTime` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '与StartTime一起作用，比如：12:00:00 EntryTimeType = 0时有效',
  `TimeSpot` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '比如：09:00:00 EntryTimeType = 2时有效',
  `SchoolID` int(10) NOT NULL,
  PRIMARY KEY (`ID`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

-- -----------------------------------------------------
-- Table `nccs`.`RfConfig`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`RfConfig` ;
CREATE TABLE IF NOT EXISTS `nccs`.`RfConfig`  (
    `PwrID` tinyint(4) NOT NULL,
    `Name` varchar(45) DEFAULT NULL COMMENT '物联名称',
    `ChildType` int(11) NOT NULL  COMMENT '物联二级类型',
    `DevID` varchar(50) NOT NULL DEFAULT '0' COMMENT '设备ID',
    UNIQUE KEY `uniqueIndex` (`PwrID`,`DevID`) USING BTREE,
    KEY `devIdIndex` (`DevID`) USING BTREE
    ) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='物联配置表基于设备';

-- -----------------------------------------------------
-- Table `nccs`.`SessionCtrlListType`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SessionCtrlListType` ;
CREATE TABLE IF NOT EXISTS `nccs`.`SessionCtrlListType`  (
    `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
    `SessionID` smallint(6) NOT NULL,
    `ChildType` int(11) NOT NULL,
    `State` int(11) DEFAULT NULL,
    `Action` int(11) DEFAULT NULL,
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE KEY `SesSubID_UNIQUE` (`SessionID`,`ChildType`) USING BTREE,
    KEY `SessionID` (`SessionID`) USING BTREE
    )ENGINE = InnoDB AUTO_INCREMENT = 1 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

-- -----------------------------------------------------
-- Table `nccs`.`RfChildType`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`RfChildType` ;

CREATE TABLE IF NOT EXISTS `nccs`.`RfChildType` (
    `ID` int(11) NOT NULL AUTO_INCREMENT COMMENT '子类型',
    `RfType` int(11) NOT NULL COMMENT '父类型',
    `Name` varchar(255) NOT NULL COMMENT '子类型名称',
    `SchoolID` int(11) NOT NULL COMMENT '学校id',
    `IsDefault` tinyint(1) NOT NULL COMMENT '0：正常子类，1：默认子类',
    PRIMARY KEY (`ID`),
    UNIQUE KEY `School_Name` (`SchoolID`,`Name`) USING BTREE
    ) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 ROW_FORMAT=DYNAMIC;

-- -----------------------------------------------------
-- Table `nccs`.`SessionNoRfCtrlList`
-- -----------------------------------------------------
DROP TABLE IF EXISTS `nccs`.`SessionNoRfCtrlList` ;
CREATE TABLE IF NOT EXISTS   `nccs`.`SessionNoRfCtrlList` (
    `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
    `SessionID` smallint(6) NOT NULL,
    `SubID` int(11) NOT NULL COMMENT '256:中控，257:屏蔽仪，258:电子时钟',
    `State` int(11) DEFAULT NULL,
    `Action` int(11) DEFAULT NULL,
    PRIMARY KEY (`id`) USING BTREE,
    UNIQUE KEY `SesSubID_Type_UNIQUE` (`SessionID`,`SubID`) USING BTREE,
    KEY `SessionID` (`SessionID`) USING BTREE
    ) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;

-- ----------------------------
-- Table structure for Graphics
-- ----------------------------
DROP TABLE IF EXISTS `Graphics`;
CREATE TABLE `Graphics`  (
  `ID` int(10) NOT NULL AUTO_INCREMENT COMMENT '模板唯一键值',
  `Name` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '模板的名称',
  `Content` longtext CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci NOT NULL COMMENT '模板的内容',
  `Url` varchar(1028) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '访问模板的url',
  `Status` tinyint(1) NOT NULL DEFAULT 0 COMMENT '模板是否已经通过审核0：待审核，1：审核通过，2：审核被拒绝',
  `LinkedDev` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '模板关联的设备的ID，一般是演讲型教室的模板',
  `Sign` int(10) UNSIGNED NOT NULL DEFAULT 0 COMMENT '表示是否有更新',
  `UpdateAt` timestamp(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0) COMMENT '更新时间',
  `SchoolID` int(10) NOT NULL COMMENT '学校ID',
  PRIMARY KEY (`ID`) USING BTREE
) ENGINE = InnoDB AUTO_INCREMENT = 38 CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;


-- ----------------------------
-- Table structure for GraphicSessionMember
-- ----------------------------
DROP TABLE IF EXISTS `GraphicSessionMember`;
CREATE TABLE `GraphicSessionMember` (
    `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
    `session` int(10) unsigned NOT NULL COMMENT 'IDSessions表id主键值',
    `device` varchar(16) NOT NULL COMMENT '设备ID',
    PRIMARY KEY (`id`),
    UNIQUE KEY `unique_idx` (`device`,`session`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;


-- ----------------------------
-- Table structure for GraphicSessions
-- ----------------------------
DROP TABLE IF EXISTS `GraphicSessions`;
CREATE TABLE `GraphicSessions` (
    `id` int(10) unsigned NOT NULL AUTO_INCREMENT COMMENT '图文任务ID',
    `name` varchar(255) NOT NULL,
    `priority` tinyint(5) unsigned NOT NULL DEFAULT '30',
    `forced` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '1表示强制接收，0表示不强制接收',
    `start_time` datetime NOT NULL COMMENT '任务开始时间',
    `stop_time` datetime NOT NULL COMMENT '任务结束时间',
    `start_time_hms` time NOT NULL COMMENT '存放start_time字段的时分秒',
    `time_style` tinyint(4) NOT NULL DEFAULT '0' COMMENT '重复周期，按照bit位重复,bit0表示周天',
    `status` tinyint(3) unsigned NOT NULL DEFAULT '0' COMMENT '0表示禁止状态，1表示停止状态，2表示运行状态',
    `resource_id` int(10) unsigned NOT NULL COMMENT '图文资源ID',
    `owner` int(11) NOT NULL COMMENT '创建者ID',
    `school_id` int(11) NOT NULL,
    `update_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
    `create_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
    `update_status_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '任务状态更新时间',
    PRIMARY KEY (`id`),
    KEY `start_time_hms_index` (`start_time_hms`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `nccs`.`OAuthUser` ;
CREATE TABLE IF NOT EXISTS `nccs`.`OAuthUser` (
    `ID` int(11) NOT NULL AUTO_INCREMENT COMMENT '主键',
    `Name` varchar(255) NOT NULL COMMENT '用户名',
    `Phone` varchar(50) NOT NULL COMMENT '电话',
    `Info` varchar(255) NOT NULL COMMENT '主要信息',
    PRIMARY KEY (`ID`),
    UNIQUE KEY `ID` (`ID`) USING BTREE,
    UNIQUE KEY `Phone` (`Phone`) USING BTREE
    ) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `nccs`.`OAuthAppInfo` ;
CREATE TABLE IF NOT EXISTS `nccs`.`OAuthAppInfo` (
    `OAuthUserID` int(11) NOT NULL COMMENT '第三方用户ID',
    `AppID` varchar(255) NOT NULL,
    `AppSecret` varchar(255) NOT NULL,
    `IsAllPrivilege` bigint(1) NOT NULL COMMENT '0:非全部，1：全部权限',
    `Privilege` varchar(255) NOT NULL COMMENT '以“,”分割的权限字符串',
    `RedirectUrl` varchar(255) NOT NULL COMMENT '回调地址',
    UNIQUE KEY `AppID` (`AppID`) USING BTREE
    ) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `nccs`.`OAuthToken` ;
CREATE TABLE  IF NOT EXISTS `nccs`.`OAuthToken` (
    `AppID` varchar(256) NOT NULL,
    `Token` varchar(255) NOT NULL,
    `TimeOut` datetime NOT NULL COMMENT '过期时间',
    UNIQUE KEY `AppID` (`AppID`) USING BTREE
    ) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `nccs`.`DevicePower` ;
CREATE TABLE IF NOT EXISTS   `nccs`.`DevicePower` (
    `DeviceID` varchar(255) NOT NULL COMMENT '设备ID',
    `StatisticDay` date NOT NULL COMMENT '日期',
    `SchoolID` int(11) NOT NULL COMMENT '学校ID',
    `SubID` int(11) NOT NULL COMMENT '0-31 表示物联。 256,257,258 表示中控、投影、二路投影',
    `PowerConsumed` int(11) NOT NULL COMMENT '单位w',
    `UsedTime` int(11) DEFAULT NULL COMMENT '单位s',
    `SubType` int(11) NOT NULL DEFAULT '0' COMMENT '设备类型，中控、投影仪1、投影1、与SubID 相同。 物联设备 为 RfType',
    UNIQUE KEY `StatisticDay` (`StatisticDay`,`DeviceID`,`SchoolID`,`SubID`,`SubType`)
    ) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `nccs`.`UserSchools`;
CREATE TABLE `nccs`.`UserSchools` (
  `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
  `user_id` int(11) NOT NULL,
  `school_id` int(11) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `userSchoolIndex` (`user_id`,`school_id`) USING BTREE,
  CONSTRAINT `uidForeignKey`
  FOREIGN KEY (`user_id`)
  REFERENCES `nccs`.`Users` (`User_ID`)
  ON DELETE CASCADE
  ON UPDATE NO ACTION)
ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;

-- ----------------------------
-- Table structure for LogicClasses
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`LogicClasses`;
CREATE TABLE `nccs`.`LogicClasses` (
  `id` int(10) NOT NULL AUTO_INCREMENT,
  `name` varchar(256) NOT NULL,
  `extend_name` varchar(255) NOT NULL DEFAULT '',
  `school_id` int(11) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `nameSchoolIndex` (`name`,`school_id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8;

-- ----------------------------
-- Table structure for LogicClassDevices
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`LogicClassDevices`;
CREATE TABLE `nccs`.`LogicClassDevices` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `class_id` int(11) NOT NULL,
  `device` varchar(50) NOT NULL,
  PRIMARY KEY (`id`),
  UNIQUE KEY `classDevIndex` (`class_id`,`device`) USING BTREE,
  KEY `devForeignKeyIndex` (`device`) USING BTREE,
  CONSTRAINT `classForeignKey` 
  FOREIGN KEY (`class_id`) 
  REFERENCES `nccs`.`LogicClasses` (`id`) 
  ON DELETE CASCADE 
  ON UPDATE NO ACTION,
  CONSTRAINT `devForeignKey` 
  FOREIGN KEY (`device`) 
  REFERENCES `nccs`.`DeviceList` (`DevID`) 
  ON DELETE CASCADE 
  ON UPDATE NO ACTION
) ENGINE=InnoDB DEFAULT CHARSET=utf8;


DROP TABLE IF EXISTS `nccs`.`Firmware`;
CREATE TABLE `nccs`.`Firmware` (
  `id` int(10) NOT NULL AUTO_INCREMENT,
  `name` varchar(256) NOT NULL,
  `chip` varchar(32) NOT NULL DEFAULT '',
  `pre` varchar(255) NOT NULL DEFAULT '',
  `md5` varchar(255) NOT NULL DEFAULT '',
  `notes` varchar(1024) NOT NULL DEFAULT '',
  `version` int(11) NOT NULL DEFAULT 0,
  `file_path` varchar(128) NOT NULL DEFAULT '',
  `school_id` int(11) NOT NULL,
  `update_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `create_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  UNIQUE KEY `nameIndex` (`name`,`school_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `nccs`.`EnvDataCh2o`;
CREATE TABLE IF NOT EXISTS `nccs`.`EnvDataCh2o`  (
    `SchoolID` int(11) NOT NULL DEFAULT 0 COMMENT '学校id',
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备ID',
    `Val` float(11, 2) NOT NULL,
    UNIQUE INDEX `INDEX`(`SchoolID`, `ReportDate`, `DeviceID`) USING BTREE
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`EnvDataCo2`;
CREATE TABLE IF NOT EXISTS `nccs`.`EnvDataCo2`  (
    `SchoolID` int(11) NOT NULL DEFAULT 0 COMMENT '学校id',
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备ID',
    `Val` float(11, 2) NOT NULL,
    UNIQUE INDEX `INDEX`(`SchoolID`, `ReportDate`, `DeviceID`) USING BTREE
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`EnvDataHumidity`;
CREATE TABLE  IF NOT EXISTS `nccs`.`EnvDataHumidity`  (
    `SchoolID` int(11) NOT NULL DEFAULT 0 COMMENT '学校id',
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备ID',
    `Val` float(11, 2) NOT NULL,
    UNIQUE INDEX `INDEX`(`SchoolID`, `ReportDate`, `DeviceID`) USING BTREE
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`EnvDataInfrared`;
CREATE TABLE IF NOT EXISTS `nccs`.`EnvDataInfrared`  (
    `SchoolID` int(11) NOT NULL DEFAULT 0 COMMENT '学校id',
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备ID',
    `Val` int(11) NOT NULL,
    UNIQUE INDEX `INDEX`(`SchoolID`, `ReportDate`, `DeviceID`) USING BTREE
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`EnvDataLight`;
CREATE TABLE IF NOT EXISTS `nccs`.`EnvDataLight`  (
    `SchoolID` int(11) NOT NULL DEFAULT 0 COMMENT '学校id',
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备ID',
    `Val` float(11, 2) NOT NULL,
    UNIQUE INDEX `INDEX`(`SchoolID`, `ReportDate`, `DeviceID`) USING BTREE
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`EnvDataNoise`;
CREATE TABLE  IF NOT EXISTS `nccs`.`EnvDataNoise`  (
    `SchoolID` int(11) NOT NULL DEFAULT 0 COMMENT '学校id',
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备ID',
    `Val` float(11, 2) NOT NULL,
    UNIQUE INDEX `INDEX`(`SchoolID`, `ReportDate`, `DeviceID`) USING BTREE
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`EnvDataPm2dot5`;
CREATE TABLE IF NOT EXISTS `nccs`.`EnvDataPm2dot5`  (
    `SchoolID` int(11) NOT NULL DEFAULT 0 COMMENT '学校id',
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备ID',
    `Val` float(11, 2) NOT NULL,
    UNIQUE INDEX `INDEX`(`SchoolID`, `ReportDate`, `DeviceID`) USING BTREE
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`EnvDataRadar`;
CREATE TABLE IF NOT EXISTS  `nccs`.`EnvDataRadar`  (
    `SchoolID` int(11) NOT NULL DEFAULT 0 COMMENT '学校id',
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备ID',
    `Val` int(11) NOT NULL,
    UNIQUE INDEX `INDEX`(`SchoolID`, `ReportDate`, `DeviceID`) USING BTREE
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`EnvDataTemperature`;
CREATE TABLE IF NOT EXISTS `nccs`.`EnvDataTemperature`  (
    `SchoolID` int(11) NOT NULL DEFAULT 0 COMMENT '学校id',
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备ID',
    `Val` float(11, 2) NOT NULL,
    UNIQUE INDEX `INDEX`(`SchoolID`, `ReportDate`, `DeviceID`) USING BTREE
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`EnvDataTvoc`;
CREATE TABLE IF NOT EXISTS  `nccs`.`EnvDataTvoc`  (
    `SchoolID` int(11) NOT NULL DEFAULT 0 COMMENT '学校id',
    `ReportDate` datetime(0) NOT NULL,
    `DeviceID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备ID',
    `Val` float(11, 2) NOT NULL,
    UNIQUE INDEX `INDEX`(`SchoolID`, `ReportDate`, `DeviceID`) USING BTREE
    ) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;


DROP TABLE IF EXISTS `nccs`.`Student` ;
CREATE TABLE IF NOT EXISTS `nccs`.`Student` (
  `Number` varchar(255) NOT NULL DEFAULT '' COMMENT '学生证号码',
  `Name` varchar(255) NOT NULL DEFAULT '' COMMENT '姓名',
  `College` varchar(255) NOT NULL DEFAULT '' COMMENT '学院',
  `Grade` int(11) NOT NULL DEFAULT '0' COMMENT '年级(毕业年份)',
  `Class` varchar(255) NOT NULL DEFAULT '' COMMENT '专业班级',
  `Mobile` varchar(255) NOT NULL DEFAULT '' COMMENT '手机号码',
  `SchoolID` int(11) NOT NULL DEFAULT '0' COMMENT '学校ID',
  PRIMARY KEY (`Number`),
  KEY `mobile` (`Mobile`),
  KEY `name` (`Name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='学生信息对接表';

DROP TABLE IF EXISTS `nccs`.`RegisterUser` ;
CREATE TABLE IF NOT EXISTS `nccs`.`RegisterUser` (
  `UserAccount` varchar(255) NOT NULL DEFAULT '' COMMENT '用户账号（下划线开头的是系统用户）',
  `Phone` varchar(255) NOT NULL DEFAULT '' COMMENT '电话号码',
  `User_ID` int(11) NOT NULL DEFAULT '-5' COMMENT '系统用户ID',
  `UserType` enum('student','teacher','other') NOT NULL DEFAULT 'student' COMMENT '用户类型（student-学生 teacher-教职工 other-其他人员）',
  `UserName` varchar(255) NOT NULL DEFAULT '' COMMENT '注册姓名',
  `UserCollege` varchar(255) NOT NULL DEFAULT '' COMMENT '注册学院',
  `UserGrade` int(11) NOT NULL DEFAULT '2019' COMMENT '注册年级',
  `UserClass` varchar(255) NOT NULL DEFAULT '' COMMENT '注册班级',
  `UserNumber` varchar(255) NOT NULL DEFAULT '' COMMENT '注册学工号',
  `SchoolID` int(11) NOT NULL DEFAULT '0' COMMENT '注册学校ID',
  `SchoolName` varchar(255) NOT NULL DEFAULT '' COMMENT '注册学校名称',
  `AddTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '注册时间',
  `ActiveTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '最后参与时间',
  `MatchStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '学生匹配状态(0-未匹配 1-匹配成功 -1-匹配失败)',
  `MatchID` int(11) NOT NULL DEFAULT '0' COMMENT '匹配ID（匹配当时 user或student 表中的ID）',
  `MatchName` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配姓名',
  `MatchCollege` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配学院',
  `MatchGrade` int(11) NOT NULL DEFAULT '2019' COMMENT '匹配年级',
  `MatchClass` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配班级',
  `MatchNumber` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配学工号',
  `MatchMobile` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配手机号码',
  `MatchSchoolID` int(11) NOT NULL DEFAULT '0' COMMENT '匹配学校ID',
  `AuditStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '审核状态（0-未审核  1-审核已通过 -1-审核未通过）',
  `AuditUserID` int(11) NOT NULL DEFAULT '0' COMMENT '审核用户ID',
  `AuditUserName` varchar(255) NOT NULL DEFAULT '' COMMENT '审核用户姓名',
  `AuditTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '审核时间',
  `ReserveTotal` int(11) NOT NULL DEFAULT '0' COMMENT '教室预约次数',
  `ReservePass` int(11) NOT NULL DEFAULT '0' COMMENT '教室预约成功次数',
  `ReserveCancel` int(11) NOT NULL DEFAULT '0' COMMENT '教室预约取消次数',
  `ReserveUse` int(11) NOT NULL DEFAULT '0' COMMENT '预约使用次数',
  `ReserveActive` int(11) NOT NULL DEFAULT '0' COMMENT '教室预约有效数量（列表可见）',
  `ReserveHistory` int(11) NOT NULL DEFAULT '0' COMMENT '历史记录数',
  PRIMARY KEY (`UserAccount`),
  KEY `phone` (`Phone`),
  KEY `userID` (`User_ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='注册用户';

DROP TABLE IF EXISTS `nccs`.`DeviceReserve` ;
CREATE TABLE IF NOT EXISTS `nccs`.`DeviceReserve` (
  `ID` int(11) NOT NULL AUTO_INCREMENT COMMENT '预约ID',
  `User_ID` int(11) NOT NULL DEFAULT '-5' COMMENT '系统用户的用户ID',
  `UserMobile` varchar(255) NOT NULL DEFAULT '' COMMENT '用户手机号码',
  `UserType` enum('student','other','teacher') NOT NULL DEFAULT 'student' COMMENT '用户类型',
  `UserName` varchar(255) NOT NULL DEFAULT '' COMMENT '姓名',
  `UserCollege` varchar(255) NOT NULL DEFAULT '' COMMENT '所属学院',
  `UserGrade` int(11) NOT NULL DEFAULT '2019' COMMENT '所属年级',
  `UserClass` varchar(255) NOT NULL DEFAULT '' COMMENT '所属班级',
  `UserNumber` varchar(255) NOT NULL DEFAULT '' COMMENT '学工号',
  `SchoolID` int(11) NOT NULL DEFAULT '0' COMMENT '申请学校ID',
  `SchoolName` varchar(255) NOT NULL DEFAULT '' COMMENT '申请学校名称',
  `MatchStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '匹配状态(0-未匹配 1-匹配成功 -1-匹配失败)',
  `MatchID` int(11) NOT NULL DEFAULT '0' COMMENT '匹配ID（匹配当时 user或student 表中的ID）',
  `MatchName` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配姓名',
  `MatchCollege` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配学院',
  `MatchGrade` int(11) NOT NULL DEFAULT '2019' COMMENT '匹配年级',
  `MatchClass` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配班级',
  `MatchNumber` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配学工号',
  `MatchMobile` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配手机号码',
  `MatchSchoolID` int(11) NOT NULL DEFAULT '0' COMMENT '匹配学校ID',
  `MatchSchoolName` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配学校',
  `ClassID` int(11) NOT NULL DEFAULT '0' COMMENT '设备分区ID',
  `ClassName` varchar(255) NOT NULL DEFAULT '' COMMENT '设备分区名称（教学楼）',
  `DeviceID` varchar(255) NOT NULL DEFAULT '' COMMENT '设备ID',
  `DeviceName` varchar(255) NOT NULL DEFAULT '' COMMENT '设备名称（教室）',
  `DeviceDescription` varchar(255) NOT NULL DEFAULT '' COMMENT '设备位置',
  `DeviceExt` varchar(255) NOT NULL DEFAULT '' COMMENT '扩展设备ID,英文逗号分割（双师课堂一个教室有两个设备）',
  `StartTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '开始时间',
  `EndTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '结束时间',
  `Reason` varchar(255) NOT NULL DEFAULT '' COMMENT '预约原因',
  `ApplyTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '申请时间',
  `ModifyTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '修改时间',
  `AuditStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '审核状态（0-未审核  1-审核未通过 2-审核已通过 -1-审核已过期）',
  `AuditUserID` int(11) NOT NULL DEFAULT '0' COMMENT '审核用户ID',
  `AuditUserName` varchar(255) NOT NULL DEFAULT '' COMMENT '审核用户姓名',
  `AuditTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '审核时间',
  `AuditInfo` varchar(255) NOT NULL DEFAULT '' COMMENT '审核备注信息',
  `CancelStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '取消状态（0-未取消  1-用户自己取消 2-管理员取消）',
  `CancelUserID` int(11) NOT NULL DEFAULT '0' COMMENT '取消用户ID （管理员取消才有值）',
  `CancelUserName` varchar(255) NOT NULL DEFAULT '' COMMENT '取消用户姓名（管理员取消才有值）',
  `CancelTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '取消时间',
  `CancelReason` varchar(255) NOT NULL DEFAULT '' COMMENT '取消原因',
  `UseQrCode` varchar(255) NOT NULL DEFAULT '' COMMENT '反向扫码二维码',
  `UseStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '使用状态（0-未使用 1-已使用）',
  `UseDeviceID` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否使用设备(0-未使用 1-已使用)',
  `UseDeviceExt` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否使用扩展设备(0-未使用 1-已使用)',
  `UseCount` int(11) NOT NULL DEFAULT '0' COMMENT '使用次数',
  `UseTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '使用时间',
  `UseDevice` varchar(255) NOT NULL DEFAULT '' COMMENT '使用设备ID',
  PRIMARY KEY (`ID`),
  KEY `mobile` (`UserMobile`),
  KEY `number` (`UserNumber`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='教室预约';

DROP TABLE IF EXISTS `nccs`.`DeviceReserveHistory` ;
CREATE TABLE IF NOT EXISTS `nccs`.`DeviceReserveHistory` (
  `ID` int(11) NOT NULL COMMENT '预约ID',
  `User_ID` int(11) NOT NULL DEFAULT '-5' COMMENT '系统用户的用户ID',
  `UserMobile` varchar(255) NOT NULL DEFAULT '' COMMENT '用户手机号码',
  `UserType` enum('student','teacher','other') NOT NULL DEFAULT 'student' COMMENT '用户类型',
  `UserName` varchar(255) NOT NULL DEFAULT '' COMMENT '姓名',
  `UserCollege` varchar(255) NOT NULL DEFAULT '' COMMENT '所属学院',
  `UserGrade` int(11) NOT NULL DEFAULT '2019' COMMENT '所属年级',
  `UserClass` varchar(255) NOT NULL DEFAULT '' COMMENT '所属班级',
  `UserNumber` varchar(255) NOT NULL DEFAULT '' COMMENT '学工号',
  `SchoolID` int(11) NOT NULL DEFAULT '0' COMMENT '申请学校ID',
  `SchoolName` varchar(255) NOT NULL DEFAULT '' COMMENT '申请学校名称',
  `MatchStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '匹配状态(0-未匹配 1-匹配成功 -1-匹配失败)',
  `MatchID` int(11) NOT NULL DEFAULT '0' COMMENT '匹配ID（匹配当时 user或student 表中的ID）',
  `MatchName` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配姓名',
  `MatchCollege` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配学院',
  `MatchGrade` int(11) NOT NULL DEFAULT '2019' COMMENT '匹配年级',
  `MatchClass` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配班级',
  `MatchNumber` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配学工号',
  `MatchMobile` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配手机号码',
  `MatchSchoolID` int(11) NOT NULL DEFAULT '0' COMMENT '匹配学校ID',
  `MatchSchoolName` varchar(255) NOT NULL DEFAULT '' COMMENT '匹配学校',
  `ClassID` int(11) NOT NULL DEFAULT '0' COMMENT '设备分区ID',
  `ClassName` varchar(255) NOT NULL DEFAULT '' COMMENT '设备分区名称（教学楼）',
  `DeviceID` varchar(255) NOT NULL DEFAULT '' COMMENT '设备ID',
  `DeviceName` varchar(255) NOT NULL DEFAULT '' COMMENT '设备名称（教室）',
  `DeviceExt` varchar(255) NOT NULL DEFAULT '' COMMENT '扩展设备ID,英文逗号分割（双师课堂一个教室有两个设备）',
  `DeviceDescription` varchar(255) NOT NULL DEFAULT '' COMMENT '设备位置',
  `StartTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '开始时间',
  `EndTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '结束时间',
  `Reason` varchar(255) NOT NULL DEFAULT '' COMMENT '预约原因',
  `ApplyTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '申请时间',
  `ModifyTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '修改时间',
  `AuditStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '审核状态（0-未审核  1-审核已通过 -1-审核未通过）',
  `AuditUserID` int(11) NOT NULL DEFAULT '0' COMMENT '审核用户ID',
  `AuditUserName` varchar(255) NOT NULL DEFAULT '' COMMENT '审核用户姓名',
  `AuditTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '审核时间',
  `AuditInfo` varchar(255) NOT NULL DEFAULT '' COMMENT '审核备注信息',
  `CancelStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '取消状态（0-未取消  1-用户自己取消 2-管理员取消）',
  `CancelUserID` int(11) NOT NULL DEFAULT '0' COMMENT '取消用户ID （管理员取消才有值）',
  `CancelUserName` varchar(255) NOT NULL DEFAULT '' COMMENT '取消用户姓名（管理员取消才有值）',
  `CancelTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '取消时间',
  `CancelReason` varchar(255) NOT NULL DEFAULT '' COMMENT '取消原因',
  `UseQrCode` varchar(255) NOT NULL DEFAULT '' COMMENT '反向扫码二维码',
  `UseStatus` tinyint(4) NOT NULL DEFAULT '0' COMMENT '使用状态（0-未使用 1-已使用）',
  `UseDeviceID` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否使用设备(0-未使用 1-已使用)',
  `UseDeviceExt` tinyint(4) NOT NULL DEFAULT '0' COMMENT '是否使用扩展设备(0-未使用 1-已使用)',
  `UseCount` int(11) NOT NULL DEFAULT '0' COMMENT '使用次数',
  `UseTime` bigint(20) NOT NULL DEFAULT '0' COMMENT '使用时间',
  `UseDevice` varchar(255) NOT NULL DEFAULT '' COMMENT '使用设备ID',
  PRIMARY KEY (`ID`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8 COMMENT='教室预约历史数据';

DROP TABLE IF EXISTS `nccs`.`DevUsedStatus`;
CREATE TABLE `nccs`.`DevUsedStatus`  (
  `DevID` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '融合终端，音视频直转播终端，mic等设备的ID(因为mic可能从一个设备挪到另一个设备使用所以单独为mic创建记录)',
  `Type` int(10) NOT NULL COMMENT '用于区分设备类型(0:融合终端 1:空调 2:电源 10:音视频直转播终端 11:麦克风 12:网关设备  )',
  `Status` enum('offline','online','pwrOn','pwrOff','using','isPushing') CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT 'offline:离线 online:在线 pwrOn:开机 pwrOff:关机 using:使用中 isPushing:推流中',
  `UpdateDate` date NOT NULL DEFAULT '2022-04-19' COMMENT 'mic和充电桩上报该状态时的时间',
  `Count` int(10) NOT NULL COMMENT '设备切换为该状态的次数',
  `SchoolID` int(10) NOT NULL COMMENT '所在学校ID',
  UNIQUE INDEX `Dev_Status_Date`(`DevID`, `Status`, `UpdateDate`, `SchoolID`, `Type`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`MicPhoneList`;
CREATE TABLE `nccs`.`MicPhoneList`  (
  `id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT 'mic的id',
  `name` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT 'mic的名称',
  `mic_type` int(32) NOT NULL DEFAULT 0 COMMENT '麦克风类型',
  `last_dev_id` varchar(255) NOT NULL DEFAULT '' COMMENT '最近一次归属的设备ID',
  `charge_count` int(32) NOT NULL DEFAULT 0 COMMENT '充电次数',
  `school_id` int(10) NOT NULL,
  `update_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `create_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`MicStubList`;
CREATE TABLE `nccs`.`MicStubList`  (
  `id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '充电桩id',
  `name` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '充电桩名称',
  `stub_type` int(32) NOT NULL DEFAULT 0 COMMENT '充电桩类型',
  `last_dev_id` varchar(255) NOT NULL DEFAULT '' COMMENT '最近一次归属的设备ID',
  `school_id` int(10) NOT NULL,
  `update_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `create_time` TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;


DROP TABLE IF EXISTS `nccs`.`SessionHistory`;
CREATE TABLE  `nccs`.`SessionHistory` (
  `SessionID` smallint(6) NOT NULL COMMENT '任务ID',
  `SessionStreamType` tinyint(4) UNSIGNED NOT NULL COMMENT '任务内容类型，与任务表相同',
  `SourceMode` tinyint(4) NOT NULL COMMENT '来源方式',
  `SessionType` tinyint(4) NOT NULL COMMENT '任务类型，与任务表相同',
  `SessionName` varchar(50) NOT NULL COMMENT '任务名称',
  `ScheduleID` int(11) NOT NULL COMMENT '执行时间ID，手动任务为0',
  `ScheduleTime` time NOT NULL COMMENT '执行时间',
  `Status` tinyint(4) NOT NULL COMMENT '执行状态 0：待执行，1:执行中，2：执行成功，3：执行失败',
  `SchoolID` int(11) NOT NULL COMMENT '学校ID',
  `HistoryDate` date NOT NULL COMMENT '任务当日时间',
  UNIQUE KEY `SessionID` (`SessionID`,`ScheduleID`,`SchoolID`,`HistoryDate`,`ScheduleTime`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `nccs`.`ReportData`;
CREATE TABLE  `nccs`.`ReportData` (
  `table_id` int(11) NOT NULL COMMENT '报表ID',
  `row_id` varchar(255) NOT NULL COMMENT '报表周期 例：按月分组 ‘2022-01’，‘2022-02’',
  `header_column_id` int(11) NOT NULL COMMENT '子项关联ID ',
  `base_id` varchar(255) NOT NULL COMMENT '按设备统计含义为 ：device_id 。按学校统计 含义为 ：school_id 按学校-设备统计：school_id-device-id ',
  `val` varchar(255) NOT NULL COMMENT '具体数据值',
  UNIQUE KEY `table_id` (`table_id`,`row_id`,`header_column_id`,`base_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8;

DROP TABLE IF EXISTS `nccs`.`DevOfflineTime`;
CREATE TABLE `nccs`.`DevOfflineTime`  (
  `dev_id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备ID',
  `type` int(11) NOT NULL COMMENT '用于区分设备类型(0:融合终端 1:空调 2:电源 10:音视频直转播终端 11:麦克风 12:网关设备  )',
  `offline_time_unix` int(11) NOT NULL COMMENT '离线时间戳',
  `update_at` timestamp(0) NOT NULL DEFAULT CURRENT_TIMESTAMP(0) ON UPDATE CURRENT_TIMESTAMP(0) COMMENT '日期和时间',
  UNIQUE INDEX `school_dev`(`dev_id`, `type`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

DROP TABLE IF EXISTS `nccs`.`ThirdClassDevices`;
CREATE TABLE `nccs`.`ThirdClassDevices`  (
    `third_class_id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
    `dev_id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
    `app_id` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
    UNIQUE INDEX `third_class_id_index`(`third_class_id`, `app_id`) USING BTREE,
    UNIQUE INDEX `dev_id_index`(`dev_id`, `app_id`) USING BTREE
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci ROW_FORMAT = Dynamic;

-- ----------------------------
-- Table structure for ThirdClassQRCode
-- ----------------------------
DROP TABLE IF EXISTS `nccs`.`ThirdClassQRCode`;
CREATE TABLE `nccs`.`ThirdClassQRCode`  (
    `dev_id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备id',
    `app_id` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT 'OpenAPI app id',
    `qrcode` varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '第三方二维码',
    UNIQUE INDEX `index`(`dev_id`, `app_id`) USING BTREE COMMENT '设备id和app_id联合索引'
) ENGINE = InnoDB CHARACTER SET = utf8 COLLATE = utf8_general_ci COMMENT = '第三方教室二维码' ROW_FORMAT = Dynamic;

SET SQL_MODE=@OLD_SQL_MODE;
SET FOREIGN_KEY_CHECKS=@OLD_FOREIGN_KEY_CHECKS;
SET UNIQUE_CHECKS=@OLD_UNIQUE_CHECKS;
